/*========================== begin_copyright_notice ============================

Copyright (C) 2017-2021 Intel Corporation

SPDX-License-Identifier: MIT

============================= end_copyright_notice ===========================*/

/*
 * !!! DO NOT EDIT THIS FILE !!!
 *
 * This file was automagically crafted by GED's model parser.
 */

#include "ged_enum_tables.h"
static ged_unsigned_enum_value_t unsignedVar0 = 1;
static ged_unsigned_enum_value_t unsignedVar1 = 2;
static ged_unsigned_enum_value_t unsignedVar2 = 4;
static ged_unsigned_enum_value_t unsignedVar3 = 8;
static ged_unsigned_enum_value_t unsignedVar4 = 16;
static ged_unsigned_enum_value_t unsignedVar5 = 32;
static ged_unsigned_enum_value_t unsignedVar6 = 0;
static ged_unsigned_enum_value_t unsignedVar7 = 3;
static ged_unsigned_enum_value_t unsignedVar8 = 5;
static ged_unsigned_enum_value_t unsignedVar9 = 6;
static ged_unsigned_enum_value_t unsignedVar10 = 7;
static ged_unsigned_enum_value_t unsignedVar11 = 9;
static ged_unsigned_enum_value_t unsignedVar12 = 10;
static ged_unsigned_enum_value_t unsignedVar13 = 11;
static ged_unsigned_enum_value_t unsignedVar14 = 12;
static ged_unsigned_enum_value_t unsignedVar15 = 13;
static ged_unsigned_enum_value_t unsignedVar16 = 14;
static ged_unsigned_enum_value_t unsignedVar17 = 15;
const ged_unsigned_enum_value_t* unsignedTable0[8] =
{
    &unsignedVar0, // 0
    &unsignedVar1, // 1
    &unsignedVar2, // 2
    &unsignedVar3, // 3
    &unsignedVar4, // 4
    &unsignedVar5, // 5
    NULL, // 6
    NULL // 7
}; // unsignedTable0[]
const ged_unsigned_enum_value_t* unsignedTable1[8] =
{
    &unsignedVar0, // 0
    NULL, // 1
    NULL, // 2
    NULL, // 3
    NULL, // 4
    NULL, // 5
    NULL, // 6
    NULL // 7
}; // unsignedTable1[]
const ged_unsigned_enum_value_t* unsignedTable2[4] =
{
    &unsignedVar6, // 0
    &unsignedVar0, // 1
    &unsignedVar1, // 2
    &unsignedVar2 // 3
}; // unsignedTable2[]
const ged_unsigned_enum_value_t* unsignedTable3[4] =
{
    &unsignedVar6, // 0
    &unsignedVar0, // 1
    NULL, // 2
    NULL // 3
}; // unsignedTable3[]
const ged_unsigned_enum_value_t* unsignedTable4[2] =
{
    &unsignedVar0, // 0
    &unsignedVar1 // 1
}; // unsignedTable4[]
const ged_unsigned_enum_value_t* unsignedTable5[8] =
{
    &unsignedVar0, // 0
    &unsignedVar1, // 1
    &unsignedVar2, // 2
    &unsignedVar3, // 3
    &unsignedVar4, // 4
    NULL, // 5
    NULL, // 6
    NULL // 7
}; // unsignedTable5[]
const ged_unsigned_enum_value_t* unsignedTable6[8] =
{
    &unsignedVar0, // 0
    &unsignedVar1, // 1
    NULL, // 2
    NULL, // 3
    NULL, // 4
    NULL, // 5
    NULL, // 6
    NULL // 7
}; // unsignedTable6[]
const ged_unsigned_enum_value_t* unsignedTable7[16] =
{
    &unsignedVar6, // 0
    NULL, // 1
    &unsignedVar1, // 2
    NULL, // 3
    NULL, // 4
    NULL, // 5
    NULL, // 6
    NULL, // 7
    NULL, // 8
    NULL, // 9
    NULL, // 10
    NULL, // 11
    NULL, // 12
    NULL, // 13
    NULL, // 14
    NULL // 15
}; // unsignedTable7[]
const ged_unsigned_enum_value_t* unsignedTable8[4] =
{
    &unsignedVar6, // 0
    &unsignedVar1, // 1
    &unsignedVar2, // 2
    &unsignedVar3 // 3
}; // unsignedTable8[]
const ged_unsigned_enum_value_t* unsignedTable9[8] =
{
    &unsignedVar0, // 0
    NULL, // 1
    &unsignedVar2, // 2
    NULL, // 3
    NULL, // 4
    NULL, // 5
    NULL, // 6
    NULL // 7
}; // unsignedTable9[]
const ged_unsigned_enum_value_t* unsignedTable10[4] =
{
    &unsignedVar6, // 0
    NULL, // 1
    NULL, // 2
    NULL // 3
}; // unsignedTable10[]
const ged_unsigned_enum_value_t* unsignedTable11[4] =
{
    NULL, // 0
    &unsignedVar0, // 1
    NULL, // 2
    NULL // 3
}; // unsignedTable11[]
const ged_unsigned_enum_value_t* unsignedTable12[16] =
{
    &unsignedVar6, // 0
    NULL, // 1
    NULL, // 2
    NULL, // 3
    NULL, // 4
    NULL, // 5
    NULL, // 6
    NULL, // 7
    NULL, // 8
    NULL, // 9
    NULL, // 10
    NULL, // 11
    NULL, // 12
    NULL, // 13
    NULL, // 14
    NULL // 15
}; // unsignedTable12[]
const ged_unsigned_enum_value_t* unsignedTable13[4] =
{
    &unsignedVar6, // 0
    &unsignedVar0, // 1
    &unsignedVar2, // 2
    &unsignedVar3 // 3
}; // unsignedTable13[]
const ged_unsigned_enum_value_t* unsignedTable14[4] =
{
    &unsignedVar0, // 0
    &unsignedVar1, // 1
    &unsignedVar2, // 2
    &unsignedVar3 // 3
}; // unsignedTable14[]
const ged_unsigned_enum_value_t* unsignedTable15[8] =
{
    &unsignedVar0, // 0
    &unsignedVar1, // 1
    &unsignedVar7, // 2
    &unsignedVar2, // 3
    &unsignedVar8, // 4
    &unsignedVar9, // 5
    &unsignedVar10, // 6
    &unsignedVar3 // 7
}; // unsignedTable15[]
const ged_unsigned_enum_value_t* unsignedTable16[8] =
{
    &unsignedVar6, // 0
    NULL, // 1
    NULL, // 2
    NULL, // 3
    NULL, // 4
    NULL, // 5
    NULL, // 6
    NULL // 7
}; // unsignedTable16[]
const ged_unsigned_enum_value_t* unsignedTable17[4] =
{
    &unsignedVar4, // 0
    &unsignedVar1, // 1
    &unsignedVar2, // 2
    &unsignedVar3 // 3
}; // unsignedTable17[]
const ged_unsigned_enum_value_t* unsignedTable18[16] =
{
    &unsignedVar0, // 0
    &unsignedVar1, // 1
    &unsignedVar7, // 2
    &unsignedVar2, // 3
    &unsignedVar8, // 4
    &unsignedVar9, // 5
    &unsignedVar10, // 6
    &unsignedVar3, // 7
    &unsignedVar11, // 8
    &unsignedVar12, // 9
    &unsignedVar13, // 10
    &unsignedVar14, // 11
    &unsignedVar15, // 12
    &unsignedVar16, // 13
    &unsignedVar17, // 14
    &unsignedVar4 // 15
}; // unsignedTable18[]
const ged_unsigned_enum_value_t* unsignedTable19[8] =
{
    NULL, // 0
    &unsignedVar1, // 1
    NULL, // 2
    NULL, // 3
    NULL, // 4
    NULL, // 5
    NULL, // 6
    NULL // 7
}; // unsignedTable19[]
const ged_unsigned_enum_value_t* unsignedTable20[16] =
{
    NULL, // 0
    NULL, // 1
    &unsignedVar1, // 2
    NULL, // 3
    NULL, // 4
    NULL, // 5
    NULL, // 6
    NULL, // 7
    NULL, // 8
    NULL, // 9
    NULL, // 10
    NULL, // 11
    NULL, // 12
    NULL, // 13
    NULL, // 14
    NULL // 15
}; // unsignedTable20[]
const ged_unsigned_enum_value_t* unsignedTable21[16] =
{
    &unsignedVar6, // 0
    &unsignedVar0, // 1
    &unsignedVar1, // 2
    &unsignedVar2, // 3
    &unsignedVar3, // 4
    &unsignedVar4, // 5
    &unsignedVar5, // 6
    NULL, // 7
    NULL, // 8
    NULL, // 9
    NULL, // 10
    NULL, // 11
    NULL, // 12
    NULL, // 13
    NULL, // 14
    &unsignedVar7 // 15
}; // unsignedTable21[]
const ged_unsigned_enum_value_t* unsignedTable22[8] =
{
    &unsignedVar6, // 0
    &unsignedVar0, // 1
    &unsignedVar1, // 2
    &unsignedVar2, // 3
    &unsignedVar3, // 4
    &unsignedVar4, // 5
    &unsignedVar5, // 6
    &unsignedVar7 // 7
}; // unsignedTable22[]
const ged_unsigned_enum_value_t* unsignedTable23[19] =
{
    &unsignedVar2, // 0
    &unsignedVar2, // 1
    &unsignedVar1, // 2
    &unsignedVar1, // 3
    &unsignedVar0, // 4
    &unsignedVar0, // 5
    &unsignedVar3, // 6
    &unsignedVar2, // 7
    NULL, // 8
    NULL, // 9
    NULL, // 10
    &unsignedVar2, // 11
    &unsignedVar2, // 12
    &unsignedVar2, // 13
    NULL, // 14
    NULL, // 15
    NULL, // 16
    NULL, // 17
    NULL // 18
}; // unsignedTable23[]
const ged_unsigned_enum_value_t* unsignedTable24[19] =
{
    &unsignedVar2, // 0
    &unsignedVar2, // 1
    &unsignedVar1, // 2
    &unsignedVar1, // 3
    &unsignedVar0, // 4
    &unsignedVar0, // 5
    &unsignedVar3, // 6
    &unsignedVar2, // 7
    &unsignedVar3, // 8
    &unsignedVar3, // 9
    &unsignedVar1, // 10
    &unsignedVar2, // 11
    &unsignedVar2, // 12
    &unsignedVar2, // 13
    NULL, // 14
    NULL, // 15
    NULL, // 16
    NULL, // 17
    NULL // 18
}; // unsignedTable24[]
const ged_unsigned_enum_value_t* unsignedTable25[19] =
{
    &unsignedVar2, // 0
    &unsignedVar2, // 1
    &unsignedVar1, // 2
    &unsignedVar1, // 3
    &unsignedVar0, // 4
    &unsignedVar0, // 5
    &unsignedVar3, // 6
    &unsignedVar2, // 7
    &unsignedVar3, // 8
    &unsignedVar3, // 9
    &unsignedVar1, // 10
    &unsignedVar2, // 11
    &unsignedVar2, // 12
    &unsignedVar2, // 13
    &unsignedVar2, // 14
    NULL, // 15
    NULL, // 16
    NULL, // 17
    NULL // 18
}; // unsignedTable25[]
const ged_unsigned_enum_value_t* unsignedTable26[19] =
{
    &unsignedVar2, // 0
    &unsignedVar2, // 1
    &unsignedVar1, // 2
    &unsignedVar1, // 3
    &unsignedVar0, // 4
    &unsignedVar0, // 5
    &unsignedVar3, // 6
    &unsignedVar2, // 7
    &unsignedVar3, // 8
    &unsignedVar3, // 9
    &unsignedVar1, // 10
    &unsignedVar2, // 11
    &unsignedVar2, // 12
    &unsignedVar2, // 13
    &unsignedVar2, // 14
    &unsignedVar1, // 15
    NULL, // 16
    NULL, // 17
    NULL // 18
}; // unsignedTable26[]
const ged_unsigned_enum_value_t* unsignedTable27[19] =
{
    &unsignedVar2, // 0
    &unsignedVar2, // 1
    &unsignedVar1, // 2
    &unsignedVar1, // 3
    &unsignedVar0, // 4
    &unsignedVar0, // 5
    &unsignedVar3, // 6
    &unsignedVar2, // 7
    &unsignedVar3, // 8
    &unsignedVar3, // 9
    &unsignedVar1, // 10
    &unsignedVar2, // 11
    &unsignedVar2, // 12
    &unsignedVar2, // 13
    NULL, // 14
    &unsignedVar1, // 15
    &unsignedVar0, // 16
    NULL, // 17
    NULL // 18
}; // unsignedTable27[]
const ged_unsigned_enum_value_t* unsignedTable28[19] =
{
    &unsignedVar2, // 0
    &unsignedVar2, // 1
    &unsignedVar1, // 2
    &unsignedVar1, // 3
    &unsignedVar0, // 4
    &unsignedVar0, // 5
    &unsignedVar3, // 6
    &unsignedVar2, // 7
    &unsignedVar3, // 8
    &unsignedVar3, // 9
    &unsignedVar1, // 10
    &unsignedVar2, // 11
    &unsignedVar2, // 12
    &unsignedVar2, // 13
    NULL, // 14
    &unsignedVar1, // 15
    NULL, // 16
    &unsignedVar0, // 17
    &unsignedVar7 // 18
}; // unsignedTable28[]
const ged_unsigned_enum_value_t* unsignedTable29[19] =
{
    &unsignedVar6, // 0
    &unsignedVar6, // 1
    &unsignedVar6, // 2
    &unsignedVar6, // 3
    &unsignedVar6, // 4
    &unsignedVar6, // 5
    &unsignedVar0, // 6
    &unsignedVar0, // 7
    NULL, // 8
    NULL, // 9
    NULL, // 10
    &unsignedVar6, // 11
    &unsignedVar6, // 12
    &unsignedVar6, // 13
    NULL, // 14
    NULL, // 15
    NULL, // 16
    NULL, // 17
    NULL // 18
}; // unsignedTable29[]
const ged_unsigned_enum_value_t* unsignedTable30[19] =
{
    &unsignedVar6, // 0
    &unsignedVar6, // 1
    &unsignedVar6, // 2
    &unsignedVar6, // 3
    &unsignedVar6, // 4
    &unsignedVar6, // 5
    &unsignedVar0, // 6
    &unsignedVar0, // 7
    &unsignedVar6, // 8
    &unsignedVar6, // 9
    &unsignedVar0, // 10
    &unsignedVar6, // 11
    &unsignedVar6, // 12
    &unsignedVar6, // 13
    NULL, // 14
    NULL, // 15
    NULL, // 16
    NULL, // 17
    NULL // 18
}; // unsignedTable30[]
const ged_unsigned_enum_value_t* unsignedTable31[19] =
{
    &unsignedVar6, // 0
    &unsignedVar6, // 1
    &unsignedVar6, // 2
    &unsignedVar6, // 3
    &unsignedVar6, // 4
    &unsignedVar6, // 5
    &unsignedVar0, // 6
    &unsignedVar0, // 7
    &unsignedVar6, // 8
    &unsignedVar6, // 9
    &unsignedVar0, // 10
    &unsignedVar6, // 11
    &unsignedVar6, // 12
    &unsignedVar6, // 13
    NULL, // 14
    &unsignedVar0, // 15
    NULL, // 16
    NULL, // 17
    NULL // 18
}; // unsignedTable31[]
const ged_unsigned_enum_value_t* unsignedTable32[19] =
{
    &unsignedVar6, // 0
    &unsignedVar6, // 1
    &unsignedVar6, // 2
    &unsignedVar6, // 3
    &unsignedVar6, // 4
    &unsignedVar6, // 5
    &unsignedVar0, // 6
    &unsignedVar0, // 7
    &unsignedVar6, // 8
    &unsignedVar6, // 9
    &unsignedVar0, // 10
    &unsignedVar6, // 11
    &unsignedVar6, // 12
    &unsignedVar6, // 13
    NULL, // 14
    &unsignedVar0, // 15
    NULL, // 16
    &unsignedVar0, // 17
    &unsignedVar0 // 18
}; // unsignedTable32[]
const ged_unsigned_enum_value_t* unsignedTable33[14] =
{
    &unsignedVar6, // 0
    &unsignedVar0, // 1
    &unsignedVar6, // 2
    &unsignedVar0, // 3
    &unsignedVar6, // 4
    &unsignedVar0, // 5
    &unsignedVar6, // 6
    &unsignedVar0, // 7
    &unsignedVar6, // 8
    &unsignedVar6, // 9
    &unsignedVar6, // 10
    &unsignedVar6, // 11
    &unsignedVar6, // 12
    &unsignedVar6 // 13
}; // unsignedTable33[]
static GED_ACCESS_MODE AccessModeVar0 = (GED_ACCESS_MODE)0;
static GED_ACCESS_MODE AccessModeVar1 = (GED_ACCESS_MODE)1;
const GED_ACCESS_MODE* AccessModeTable0[2] =
{
    &AccessModeVar0, // 0
    &AccessModeVar1 // 1
}; // AccessModeTable0[]
const GED_ACCESS_MODE* AccessModeTable1[2] =
{
    NULL, // 0
    &AccessModeVar1 // 1
}; // AccessModeTable1[]
static GED_ACC_WR_CTRL AccWrCtrlVar0 = (GED_ACC_WR_CTRL)0;
static GED_ACC_WR_CTRL AccWrCtrlVar1 = (GED_ACC_WR_CTRL)1;
const GED_ACC_WR_CTRL* AccWrCtrlTable0[2] =
{
    &AccWrCtrlVar0, // 0
    &AccWrCtrlVar1 // 1
}; // AccWrCtrlTable0[]
static GED_ADDR_MODE AddrModeVar0 = (GED_ADDR_MODE)0;
static GED_ADDR_MODE AddrModeVar1 = (GED_ADDR_MODE)1;
const GED_ADDR_MODE* AddrModeTable0[2] =
{
    &AddrModeVar0, // 0
    &AddrModeVar1 // 1
}; // AddrModeTable0[]
const GED_ADDR_MODE* AddrModeTable1[2] =
{
    &AddrModeVar0, // 0
    NULL // 1
}; // AddrModeTable1[]
static GED_ARCH_REG ArchRegVar0 = (GED_ARCH_REG)0;
static GED_ARCH_REG ArchRegVar1 = (GED_ARCH_REG)1;
static GED_ARCH_REG ArchRegVar2 = (GED_ARCH_REG)2;
static GED_ARCH_REG ArchRegVar3 = (GED_ARCH_REG)3;
static GED_ARCH_REG ArchRegVar4 = (GED_ARCH_REG)4;
static GED_ARCH_REG ArchRegVar5 = (GED_ARCH_REG)5;
static GED_ARCH_REG ArchRegVar6 = (GED_ARCH_REG)6;
static GED_ARCH_REG ArchRegVar7 = (GED_ARCH_REG)7;
static GED_ARCH_REG ArchRegVar8 = (GED_ARCH_REG)8;
static GED_ARCH_REG ArchRegVar9 = (GED_ARCH_REG)9;
static GED_ARCH_REG ArchRegVar10 = (GED_ARCH_REG)10;
static GED_ARCH_REG ArchRegVar11 = (GED_ARCH_REG)11;
static GED_ARCH_REG ArchRegVar12 = (GED_ARCH_REG)12;
static GED_ARCH_REG ArchRegVar13 = (GED_ARCH_REG)13;
static GED_ARCH_REG ArchRegVar14 = (GED_ARCH_REG)14;
const GED_ARCH_REG* ArchRegTable0[16] =
{
    &ArchRegVar0, // 0
    &ArchRegVar1, // 1
    &ArchRegVar2, // 2
    &ArchRegVar3, // 3
    &ArchRegVar4, // 4
    &ArchRegVar5, // 5
    &ArchRegVar6, // 6
    &ArchRegVar7, // 7
    &ArchRegVar8, // 8
    &ArchRegVar9, // 9
    &ArchRegVar10, // 10
    &ArchRegVar11, // 11
    &ArchRegVar12, // 12
    &ArchRegVar13, // 13
    NULL, // 14
    &ArchRegVar14 // 15
}; // ArchRegTable0[]
const GED_ARCH_REG* ArchRegTable1[16] =
{
    &ArchRegVar0, // 0
    &ArchRegVar1, // 1
    &ArchRegVar2, // 2
    &ArchRegVar3, // 3
    &ArchRegVar4, // 4
    &ArchRegVar5, // 5
    NULL, // 6
    &ArchRegVar7, // 7
    &ArchRegVar8, // 8
    &ArchRegVar9, // 9
    &ArchRegVar10, // 10
    &ArchRegVar11, // 11
    &ArchRegVar12, // 12
    &ArchRegVar13, // 13
    NULL, // 14
    &ArchRegVar14 // 15
}; // ArchRegTable1[]
const GED_ARCH_REG* ArchRegTable2[16] =
{
    &ArchRegVar0, // 0
    &ArchRegVar1, // 1
    &ArchRegVar2, // 2
    &ArchRegVar3, // 3
    &ArchRegVar4, // 4
    NULL, // 5
    NULL, // 6
    &ArchRegVar7, // 7
    &ArchRegVar8, // 8
    &ArchRegVar9, // 9
    &ArchRegVar10, // 10
    &ArchRegVar11, // 11
    &ArchRegVar12, // 12
    NULL, // 13
    NULL, // 14
    &ArchRegVar14 // 15
}; // ArchRegTable2[]
const GED_ARCH_REG* ArchRegTable3[16] =
{
    &ArchRegVar0, // 0
    &ArchRegVar1, // 1
    &ArchRegVar2, // 2
    &ArchRegVar3, // 3
    &ArchRegVar4, // 4
    NULL, // 5
    &ArchRegVar6, // 6
    &ArchRegVar7, // 7
    &ArchRegVar8, // 8
    &ArchRegVar9, // 9
    &ArchRegVar10, // 10
    &ArchRegVar11, // 11
    &ArchRegVar12, // 12
    &ArchRegVar13, // 13
    NULL, // 14
    &ArchRegVar14 // 15
}; // ArchRegTable3[]
static GED_ATOMIC_OPERATION_TYPE AtomicOperationTypeVar0 = (GED_ATOMIC_OPERATION_TYPE)0;
static GED_ATOMIC_OPERATION_TYPE AtomicOperationTypeVar1 = (GED_ATOMIC_OPERATION_TYPE)1;
static GED_ATOMIC_OPERATION_TYPE AtomicOperationTypeVar2 = (GED_ATOMIC_OPERATION_TYPE)2;
static GED_ATOMIC_OPERATION_TYPE AtomicOperationTypeVar3 = (GED_ATOMIC_OPERATION_TYPE)3;
static GED_ATOMIC_OPERATION_TYPE AtomicOperationTypeVar4 = (GED_ATOMIC_OPERATION_TYPE)4;
static GED_ATOMIC_OPERATION_TYPE AtomicOperationTypeVar5 = (GED_ATOMIC_OPERATION_TYPE)5;
static GED_ATOMIC_OPERATION_TYPE AtomicOperationTypeVar6 = (GED_ATOMIC_OPERATION_TYPE)6;
static GED_ATOMIC_OPERATION_TYPE AtomicOperationTypeVar7 = (GED_ATOMIC_OPERATION_TYPE)7;
static GED_ATOMIC_OPERATION_TYPE AtomicOperationTypeVar8 = (GED_ATOMIC_OPERATION_TYPE)8;
static GED_ATOMIC_OPERATION_TYPE AtomicOperationTypeVar9 = (GED_ATOMIC_OPERATION_TYPE)9;
static GED_ATOMIC_OPERATION_TYPE AtomicOperationTypeVar10 = (GED_ATOMIC_OPERATION_TYPE)10;
static GED_ATOMIC_OPERATION_TYPE AtomicOperationTypeVar11 = (GED_ATOMIC_OPERATION_TYPE)11;
static GED_ATOMIC_OPERATION_TYPE AtomicOperationTypeVar12 = (GED_ATOMIC_OPERATION_TYPE)12;
static GED_ATOMIC_OPERATION_TYPE AtomicOperationTypeVar13 = (GED_ATOMIC_OPERATION_TYPE)13;
static GED_ATOMIC_OPERATION_TYPE AtomicOperationTypeVar14 = (GED_ATOMIC_OPERATION_TYPE)14;
const GED_ATOMIC_OPERATION_TYPE* AtomicOperationTypeTable0[16] =
{
    NULL, // 0
    &AtomicOperationTypeVar0, // 1
    &AtomicOperationTypeVar1, // 2
    &AtomicOperationTypeVar2, // 3
    &AtomicOperationTypeVar3, // 4
    &AtomicOperationTypeVar4, // 5
    &AtomicOperationTypeVar5, // 6
    &AtomicOperationTypeVar6, // 7
    &AtomicOperationTypeVar7, // 8
    &AtomicOperationTypeVar8, // 9
    &AtomicOperationTypeVar9, // 10
    &AtomicOperationTypeVar10, // 11
    &AtomicOperationTypeVar11, // 12
    &AtomicOperationTypeVar12, // 13
    &AtomicOperationTypeVar13, // 14
    &AtomicOperationTypeVar14 // 15
}; // AtomicOperationTypeTable0[]
const GED_ATOMIC_OPERATION_TYPE* AtomicOperationTypeTable1[16] =
{
    NULL, // 0
    &AtomicOperationTypeVar0, // 1
    &AtomicOperationTypeVar1, // 2
    &AtomicOperationTypeVar2, // 3
    &AtomicOperationTypeVar3, // 4
    &AtomicOperationTypeVar4, // 5
    &AtomicOperationTypeVar5, // 6
    &AtomicOperationTypeVar6, // 7
    &AtomicOperationTypeVar7, // 8
    &AtomicOperationTypeVar8, // 9
    &AtomicOperationTypeVar9, // 10
    &AtomicOperationTypeVar10, // 11
    &AtomicOperationTypeVar11, // 12
    &AtomicOperationTypeVar12, // 13
    NULL, // 14
    &AtomicOperationTypeVar14 // 15
}; // AtomicOperationTypeTable1[]
static GED_BLOCK_SIZE BlockSizeVar0 = (GED_BLOCK_SIZE)0;
static GED_BLOCK_SIZE BlockSizeVar1 = (GED_BLOCK_SIZE)1;
static GED_BLOCK_SIZE BlockSizeVar2 = (GED_BLOCK_SIZE)2;
static GED_BLOCK_SIZE BlockSizeVar3 = (GED_BLOCK_SIZE)3;
static GED_BLOCK_SIZE BlockSizeVar4 = (GED_BLOCK_SIZE)4;
const GED_BLOCK_SIZE* BlockSizeTable0[8] =
{
    &BlockSizeVar0, // 0
    &BlockSizeVar1, // 1
    &BlockSizeVar2, // 2
    &BlockSizeVar3, // 3
    &BlockSizeVar4, // 4
    NULL, // 5
    NULL, // 6
    NULL // 7
}; // BlockSizeTable0[]
static GED_BRANCH_CTRL BranchCtrlVar0 = (GED_BRANCH_CTRL)0;
static GED_BRANCH_CTRL BranchCtrlVar1 = (GED_BRANCH_CTRL)1;
const GED_BRANCH_CTRL* BranchCtrlTable0[2] =
{
    &BranchCtrlVar0, // 0
    &BranchCtrlVar1 // 1
}; // BranchCtrlTable0[]
static GED_CHANNEL_MASK ChannelMaskVar0 = (GED_CHANNEL_MASK)0;
static GED_CHANNEL_MASK ChannelMaskVar1 = (GED_CHANNEL_MASK)1;
static GED_CHANNEL_MASK ChannelMaskVar2 = (GED_CHANNEL_MASK)2;
static GED_CHANNEL_MASK ChannelMaskVar3 = (GED_CHANNEL_MASK)3;
static GED_CHANNEL_MASK ChannelMaskVar4 = (GED_CHANNEL_MASK)4;
const GED_CHANNEL_MASK* ChannelMaskTable0[2] =
{
    &ChannelMaskVar0, // 0
    &ChannelMaskVar1 // 1
}; // ChannelMaskTable0[]
const GED_CHANNEL_MASK* ChannelMaskTable1[2] =
{
    &ChannelMaskVar2, // 0
    &ChannelMaskVar1 // 1
}; // ChannelMaskTable1[]
const GED_CHANNEL_MASK* ChannelMaskTable2[2] =
{
    &ChannelMaskVar3, // 0
    &ChannelMaskVar1 // 1
}; // ChannelMaskTable2[]
const GED_CHANNEL_MASK* ChannelMaskTable3[2] =
{
    &ChannelMaskVar4, // 0
    &ChannelMaskVar1 // 1
}; // ChannelMaskTable3[]
static GED_CHANNEL_MODE ChannelModeVar0 = (GED_CHANNEL_MODE)0;
static GED_CHANNEL_MODE ChannelModeVar1 = (GED_CHANNEL_MODE)1;
const GED_CHANNEL_MODE* ChannelModeTable0[2] =
{
    &ChannelModeVar0, // 0
    &ChannelModeVar1 // 1
}; // ChannelModeTable0[]
static GED_CHANNEL_OFFSET ChannelOffsetVar0 = (GED_CHANNEL_OFFSET)0;
static GED_CHANNEL_OFFSET ChannelOffsetVar1 = (GED_CHANNEL_OFFSET)1;
static GED_CHANNEL_OFFSET ChannelOffsetVar2 = (GED_CHANNEL_OFFSET)2;
static GED_CHANNEL_OFFSET ChannelOffsetVar3 = (GED_CHANNEL_OFFSET)3;
static GED_CHANNEL_OFFSET ChannelOffsetVar4 = (GED_CHANNEL_OFFSET)4;
static GED_CHANNEL_OFFSET ChannelOffsetVar5 = (GED_CHANNEL_OFFSET)5;
static GED_CHANNEL_OFFSET ChannelOffsetVar6 = (GED_CHANNEL_OFFSET)6;
static GED_CHANNEL_OFFSET ChannelOffsetVar7 = (GED_CHANNEL_OFFSET)7;
const GED_CHANNEL_OFFSET* ChannelOffsetTable0[8] =
{
    &ChannelOffsetVar0, // 0
    &ChannelOffsetVar1, // 1
    &ChannelOffsetVar2, // 2
    &ChannelOffsetVar3, // 3
    &ChannelOffsetVar4, // 4
    &ChannelOffsetVar5, // 5
    &ChannelOffsetVar6, // 6
    &ChannelOffsetVar7 // 7
}; // ChannelOffsetTable0[]
const GED_CHANNEL_OFFSET* ChannelOffsetTable1[4] =
{
    &ChannelOffsetVar0, // 0
    &ChannelOffsetVar2, // 1
    &ChannelOffsetVar4, // 2
    &ChannelOffsetVar6 // 3
}; // ChannelOffsetTable1[]
static GED_COND_MODIFIER CondModifierVar0 = (GED_COND_MODIFIER)0;
static GED_COND_MODIFIER CondModifierVar1 = (GED_COND_MODIFIER)1;
static GED_COND_MODIFIER CondModifierVar2 = (GED_COND_MODIFIER)2;
static GED_COND_MODIFIER CondModifierVar3 = (GED_COND_MODIFIER)3;
static GED_COND_MODIFIER CondModifierVar4 = (GED_COND_MODIFIER)4;
static GED_COND_MODIFIER CondModifierVar5 = (GED_COND_MODIFIER)5;
static GED_COND_MODIFIER CondModifierVar6 = (GED_COND_MODIFIER)6;
static GED_COND_MODIFIER CondModifierVar7 = (GED_COND_MODIFIER)7;
static GED_COND_MODIFIER CondModifierVar8 = (GED_COND_MODIFIER)8;
const GED_COND_MODIFIER* CondModifierTable0[16] =
{
    &CondModifierVar0, // 0
    &CondModifierVar1, // 1
    &CondModifierVar2, // 2
    &CondModifierVar3, // 3
    &CondModifierVar4, // 4
    &CondModifierVar5, // 5
    &CondModifierVar6, // 6
    NULL, // 7
    &CondModifierVar7, // 8
    &CondModifierVar8, // 9
    NULL, // 10
    NULL, // 11
    NULL, // 12
    NULL, // 13
    NULL, // 14
    NULL // 15
}; // CondModifierTable0[]
const GED_COND_MODIFIER* CondModifierTable1[4] =
{
    &CondModifierVar0, // 0
    &CondModifierVar1, // 1
    &CondModifierVar3, // 2
    &CondModifierVar5 // 3
}; // CondModifierTable1[]
static GED_DATA_TYPE DataTypeVar0 = (GED_DATA_TYPE)0;
static GED_DATA_TYPE DataTypeVar1 = (GED_DATA_TYPE)1;
static GED_DATA_TYPE DataTypeVar2 = (GED_DATA_TYPE)2;
static GED_DATA_TYPE DataTypeVar3 = (GED_DATA_TYPE)3;
static GED_DATA_TYPE DataTypeVar4 = (GED_DATA_TYPE)4;
static GED_DATA_TYPE DataTypeVar5 = (GED_DATA_TYPE)5;
static GED_DATA_TYPE DataTypeVar6 = (GED_DATA_TYPE)6;
static GED_DATA_TYPE DataTypeVar7 = (GED_DATA_TYPE)7;
static GED_DATA_TYPE DataTypeVar8 = (GED_DATA_TYPE)8;
static GED_DATA_TYPE DataTypeVar9 = (GED_DATA_TYPE)9;
static GED_DATA_TYPE DataTypeVar10 = (GED_DATA_TYPE)10;
static GED_DATA_TYPE DataTypeVar11 = (GED_DATA_TYPE)11;
static GED_DATA_TYPE DataTypeVar12 = (GED_DATA_TYPE)12;
static GED_DATA_TYPE DataTypeVar13 = (GED_DATA_TYPE)13;
static GED_DATA_TYPE DataTypeVar14 = (GED_DATA_TYPE)14;
static GED_DATA_TYPE DataTypeVar15 = (GED_DATA_TYPE)15;
static GED_DATA_TYPE DataTypeVar16 = (GED_DATA_TYPE)16;
static GED_DATA_TYPE DataTypeVar17 = (GED_DATA_TYPE)17;
static GED_DATA_TYPE DataTypeVar18 = (GED_DATA_TYPE)18;
const GED_DATA_TYPE* DataTypeTable0[16] =
{
    &DataTypeVar0, // 0
    &DataTypeVar1, // 1
    &DataTypeVar2, // 2
    &DataTypeVar3, // 3
    &DataTypeVar4, // 4
    &DataTypeVar5, // 5
    &DataTypeVar6, // 6
    &DataTypeVar7, // 7
    &DataTypeVar8, // 8
    &DataTypeVar9, // 9
    &DataTypeVar10, // 10
    NULL, // 11
    NULL, // 12
    NULL, // 13
    NULL, // 14
    NULL // 15
}; // DataTypeTable0[]
const GED_DATA_TYPE* DataTypeTable1[16] =
{
    &DataTypeVar0, // 0
    NULL, // 1
    NULL, // 2
    NULL, // 3
    NULL, // 4
    NULL, // 5
    NULL, // 6
    NULL, // 7
    NULL, // 8
    NULL, // 9
    NULL, // 10
    NULL, // 11
    NULL, // 12
    NULL, // 13
    NULL, // 14
    NULL // 15
}; // DataTypeTable1[]
const GED_DATA_TYPE* DataTypeTable2[16] =
{
    NULL, // 0
    &DataTypeVar1, // 1
    NULL, // 2
    NULL, // 3
    NULL, // 4
    NULL, // 5
    NULL, // 6
    NULL, // 7
    NULL, // 8
    NULL, // 9
    NULL, // 10
    NULL, // 11
    NULL, // 12
    NULL, // 13
    NULL, // 14
    NULL // 15
}; // DataTypeTable2[]
const GED_DATA_TYPE* DataTypeTable3[16] =
{
    &DataTypeVar0, // 0
    &DataTypeVar1, // 1
    &DataTypeVar2, // 2
    &DataTypeVar3, // 3
    &DataTypeVar11, // 4
    &DataTypeVar12, // 5
    &DataTypeVar13, // 6
    &DataTypeVar7, // 7
    NULL, // 8
    NULL, // 9
    NULL, // 10
    &DataTypeVar10, // 11
    NULL, // 12
    NULL, // 13
    NULL, // 14
    NULL // 15
}; // DataTypeTable3[]
const GED_DATA_TYPE* DataTypeTable4[16] =
{
    &DataTypeVar0, // 0
    &DataTypeVar1, // 1
    &DataTypeVar2, // 2
    &DataTypeVar3, // 3
    &DataTypeVar11, // 4
    &DataTypeVar12, // 5
    &DataTypeVar13, // 6
    &DataTypeVar7, // 7
    &DataTypeVar8, // 8
    &DataTypeVar9, // 9
    &DataTypeVar6, // 10
    &DataTypeVar10, // 11
    NULL, // 12
    NULL, // 13
    NULL, // 14
    NULL // 15
}; // DataTypeTable4[]
const GED_DATA_TYPE* DataTypeTable5[8] =
{
    &DataTypeVar7, // 0
    &DataTypeVar1, // 1
    &DataTypeVar0, // 2
    &DataTypeVar6, // 3
    &DataTypeVar10, // 4
    NULL, // 5
    NULL, // 6
    NULL // 7
}; // DataTypeTable5[]
const GED_DATA_TYPE* DataTypeTable6[2] =
{
    &DataTypeVar7, // 0
    &DataTypeVar10 // 1
}; // DataTypeTable6[]
const GED_DATA_TYPE* DataTypeTable7[8] =
{
    &DataTypeVar10, // 0
    &DataTypeVar7, // 1
    &DataTypeVar6, // 2
    NULL, // 3
    NULL, // 4
    NULL, // 5
    NULL, // 6
    NULL // 7
}; // DataTypeTable7[]
const GED_DATA_TYPE* DataTypeTable8[8] =
{
    &DataTypeVar0, // 0
    &DataTypeVar1, // 1
    &DataTypeVar2, // 2
    &DataTypeVar3, // 3
    &DataTypeVar4, // 4
    &DataTypeVar5, // 5
    NULL, // 6
    NULL // 7
}; // DataTypeTable8[]
const GED_DATA_TYPE* DataTypeTable9[16] =
{
    &DataTypeVar0, // 0
    &DataTypeVar1, // 1
    &DataTypeVar2, // 2
    &DataTypeVar3, // 3
    &DataTypeVar4, // 4
    &DataTypeVar5, // 5
    &DataTypeVar8, // 6
    &DataTypeVar9, // 7
    &DataTypeVar10, // 8
    &DataTypeVar7, // 9
    &DataTypeVar6, // 10
    &DataTypeVar14, // 11
    NULL, // 12
    NULL, // 13
    NULL, // 14
    NULL // 15
}; // DataTypeTable9[]
const GED_DATA_TYPE* DataTypeTable10[16] =
{
    &DataTypeVar0, // 0
    &DataTypeVar1, // 1
    &DataTypeVar2, // 2
    &DataTypeVar3, // 3
    &DataTypeVar11, // 4
    &DataTypeVar13, // 5
    NULL, // 6
    NULL, // 7
    &DataTypeVar10, // 8
    &DataTypeVar7, // 9
    NULL, // 10
    &DataTypeVar12, // 11
    NULL, // 12
    NULL, // 13
    NULL, // 14
    NULL // 15
}; // DataTypeTable10[]
const GED_DATA_TYPE* DataTypeTable11[16] =
{
    &DataTypeVar0, // 0
    &DataTypeVar1, // 1
    &DataTypeVar2, // 2
    &DataTypeVar3, // 3
    &DataTypeVar11, // 4
    &DataTypeVar13, // 5
    &DataTypeVar8, // 6
    &DataTypeVar9, // 7
    &DataTypeVar10, // 8
    &DataTypeVar7, // 9
    &DataTypeVar6, // 10
    &DataTypeVar12, // 11
    NULL, // 12
    NULL, // 13
    NULL, // 14
    NULL // 15
}; // DataTypeTable11[]
const GED_DATA_TYPE* DataTypeTable12[8] =
{
    &DataTypeVar10, // 0
    &DataTypeVar7, // 1
    &DataTypeVar6, // 2
    &DataTypeVar14, // 3
    NULL, // 4
    NULL, // 5
    NULL, // 6
    NULL // 7
}; // DataTypeTable12[]
const GED_DATA_TYPE* DataTypeTable13[16] =
{
    &DataTypeVar4, // 0
    &DataTypeVar2, // 1
    &DataTypeVar0, // 2
    &DataTypeVar8, // 3
    &DataTypeVar5, // 4
    &DataTypeVar3, // 5
    &DataTypeVar1, // 6
    &DataTypeVar9, // 7
    NULL, // 8
    &DataTypeVar10, // 9
    &DataTypeVar7, // 10
    &DataTypeVar6, // 11
    NULL, // 12
    NULL, // 13
    NULL, // 14
    NULL // 15
}; // DataTypeTable13[]
const GED_DATA_TYPE* DataTypeTable14[16] =
{
    NULL, // 0
    NULL, // 1
    &DataTypeVar0, // 2
    NULL, // 3
    NULL, // 4
    NULL, // 5
    NULL, // 6
    NULL, // 7
    NULL, // 8
    NULL, // 9
    NULL, // 10
    NULL, // 11
    NULL, // 12
    NULL, // 13
    NULL, // 14
    NULL // 15
}; // DataTypeTable14[]
const GED_DATA_TYPE* DataTypeTable15[16] =
{
    &DataTypeVar11, // 0
    &DataTypeVar2, // 1
    &DataTypeVar0, // 2
    NULL, // 3
    &DataTypeVar13, // 4
    &DataTypeVar3, // 5
    &DataTypeVar1, // 6
    NULL, // 7
    &DataTypeVar12, // 8
    &DataTypeVar10, // 9
    &DataTypeVar7, // 10
    NULL, // 11
    NULL, // 12
    NULL, // 13
    NULL, // 14
    NULL // 15
}; // DataTypeTable15[]
const GED_DATA_TYPE* DataTypeTable16[16] =
{
    &DataTypeVar11, // 0
    &DataTypeVar2, // 1
    &DataTypeVar0, // 2
    &DataTypeVar8, // 3
    &DataTypeVar13, // 4
    &DataTypeVar3, // 5
    &DataTypeVar1, // 6
    &DataTypeVar9, // 7
    &DataTypeVar12, // 8
    &DataTypeVar10, // 9
    &DataTypeVar7, // 10
    &DataTypeVar6, // 11
    NULL, // 12
    NULL, // 13
    NULL, // 14
    NULL // 15
}; // DataTypeTable16[]
const GED_DATA_TYPE* DataTypeTable17[8] =
{
    NULL, // 0
    &DataTypeVar10, // 1
    &DataTypeVar7, // 2
    &DataTypeVar6, // 3
    NULL, // 4
    NULL, // 5
    NULL, // 6
    &DataTypeVar14 // 7
}; // DataTypeTable17[]
const GED_DATA_TYPE* DataTypeTable18[8] =
{
    &DataTypeVar4, // 0
    &DataTypeVar2, // 1
    &DataTypeVar0, // 2
    &DataTypeVar8, // 3
    &DataTypeVar5, // 4
    &DataTypeVar3, // 5
    &DataTypeVar1, // 6
    &DataTypeVar9 // 7
}; // DataTypeTable18[]
const GED_DATA_TYPE* DataTypeTable19[16] =
{
    &DataTypeVar4, // 0
    &DataTypeVar2, // 1
    &DataTypeVar0, // 2
    &DataTypeVar8, // 3
    &DataTypeVar5, // 4
    &DataTypeVar3, // 5
    &DataTypeVar1, // 6
    &DataTypeVar9, // 7
    NULL, // 8
    &DataTypeVar10, // 9
    &DataTypeVar7, // 10
    &DataTypeVar6, // 11
    NULL, // 12
    &DataTypeVar15, // 13
    NULL, // 14
    NULL // 15
}; // DataTypeTable19[]
const GED_DATA_TYPE* DataTypeTable20[8] =
{
    NULL, // 0
    &DataTypeVar10, // 1
    &DataTypeVar7, // 2
    &DataTypeVar6, // 3
    NULL, // 4
    &DataTypeVar15, // 5
    NULL, // 6
    &DataTypeVar14 // 7
}; // DataTypeTable20[]
const GED_DATA_TYPE* DataTypeTable21[8] =
{
    NULL, // 0
    &DataTypeVar10, // 1
    &DataTypeVar7, // 2
    NULL, // 3
    NULL, // 4
    &DataTypeVar15, // 5
    NULL, // 6
    NULL // 7
}; // DataTypeTable21[]
const GED_DATA_TYPE* DataTypeTable22[8] =
{
    NULL, // 0
    &DataTypeVar10, // 1
    NULL, // 2
    NULL, // 3
    NULL, // 4
    &DataTypeVar15, // 5
    NULL, // 6
    NULL // 7
}; // DataTypeTable22[]
const GED_DATA_TYPE* DataTypeTable23[8] =
{
    &DataTypeVar4, // 0
    NULL, // 1
    NULL, // 2
    NULL, // 3
    &DataTypeVar5, // 4
    NULL, // 5
    NULL, // 6
    NULL // 7
}; // DataTypeTable23[]
const GED_DATA_TYPE* DataTypeTable24[16] =
{
    &DataTypeVar4, // 0
    &DataTypeVar2, // 1
    &DataTypeVar0, // 2
    &DataTypeVar8, // 3
    &DataTypeVar5, // 4
    &DataTypeVar3, // 5
    &DataTypeVar1, // 6
    &DataTypeVar9, // 7
    &DataTypeVar16, // 8
    &DataTypeVar10, // 9
    &DataTypeVar7, // 10
    &DataTypeVar6, // 11
    NULL, // 12
    &DataTypeVar15, // 13
    NULL, // 14
    NULL // 15
}; // DataTypeTable24[]
const GED_DATA_TYPE* DataTypeTable25[16] =
{
    &DataTypeVar11, // 0
    &DataTypeVar2, // 1
    &DataTypeVar0, // 2
    NULL, // 3
    &DataTypeVar13, // 4
    &DataTypeVar3, // 5
    &DataTypeVar1, // 6
    NULL, // 7
    &DataTypeVar12, // 8
    &DataTypeVar10, // 9
    &DataTypeVar7, // 10
    NULL, // 11
    NULL, // 12
    &DataTypeVar15, // 13
    NULL, // 14
    NULL // 15
}; // DataTypeTable25[]
const GED_DATA_TYPE* DataTypeTable26[16] =
{
    &DataTypeVar11, // 0
    &DataTypeVar2, // 1
    &DataTypeVar0, // 2
    &DataTypeVar8, // 3
    &DataTypeVar13, // 4
    &DataTypeVar3, // 5
    &DataTypeVar1, // 6
    &DataTypeVar9, // 7
    &DataTypeVar12, // 8
    &DataTypeVar10, // 9
    &DataTypeVar7, // 10
    &DataTypeVar6, // 11
    NULL, // 12
    &DataTypeVar15, // 13
    NULL, // 14
    NULL // 15
}; // DataTypeTable26[]
const GED_DATA_TYPE* DataTypeTable27[16] =
{
    NULL, // 0
    NULL, // 1
    &DataTypeVar0, // 2
    NULL, // 3
    NULL, // 4
    NULL, // 5
    &DataTypeVar1, // 6
    NULL, // 7
    NULL, // 8
    NULL, // 9
    NULL, // 10
    NULL, // 11
    NULL, // 12
    NULL, // 13
    NULL, // 14
    NULL // 15
}; // DataTypeTable27[]
const GED_DATA_TYPE* DataTypeTable28[8] =
{
    NULL, // 0
    &DataTypeVar10, // 1
    &DataTypeVar7, // 2
    &DataTypeVar6, // 3
    NULL, // 4
    NULL, // 5
    NULL, // 6
    NULL // 7
}; // DataTypeTable28[]
const GED_DATA_TYPE* DataTypeTable29[8] =
{
    NULL, // 0
    &DataTypeVar10, // 1
    &DataTypeVar7, // 2
    &DataTypeVar6, // 3
    NULL, // 4
    &DataTypeVar15, // 5
    NULL, // 6
    NULL // 7
}; // DataTypeTable29[]
const GED_DATA_TYPE* DataTypeTable30[16] =
{
    &DataTypeVar4, // 0
    &DataTypeVar2, // 1
    &DataTypeVar0, // 2
    &DataTypeVar8, // 3
    &DataTypeVar5, // 4
    &DataTypeVar3, // 5
    &DataTypeVar1, // 6
    &DataTypeVar9, // 7
    &DataTypeVar17, // 8
    &DataTypeVar10, // 9
    &DataTypeVar7, // 10
    &DataTypeVar6, // 11
    NULL, // 12
    &DataTypeVar15, // 13
    &DataTypeVar18, // 14
    NULL // 15
}; // DataTypeTable30[]
const GED_DATA_TYPE* DataTypeTable31[16] =
{
    NULL, // 0
    NULL, // 1
    NULL, // 2
    NULL, // 3
    NULL, // 4
    NULL, // 5
    NULL, // 6
    NULL, // 7
    &DataTypeVar17, // 8
    &DataTypeVar10, // 9
    NULL, // 10
    NULL, // 11
    NULL, // 12
    NULL, // 13
    NULL, // 14
    NULL // 15
}; // DataTypeTable31[]
const GED_DATA_TYPE* DataTypeTable32[16] =
{
    NULL, // 0
    NULL, // 1
    NULL, // 2
    NULL, // 3
    NULL, // 4
    NULL, // 5
    NULL, // 6
    NULL, // 7
    NULL, // 8
    &DataTypeVar10, // 9
    &DataTypeVar7, // 10
    NULL, // 11
    NULL, // 12
    NULL, // 13
    NULL, // 14
    NULL // 15
}; // DataTypeTable32[]
const GED_DATA_TYPE* DataTypeTable33[8] =
{
    &DataTypeVar17, // 0
    &DataTypeVar10, // 1
    NULL, // 2
    &DataTypeVar6, // 3
    NULL, // 4
    &DataTypeVar15, // 5
    &DataTypeVar18, // 6
    NULL // 7
}; // DataTypeTable33[]
const GED_DATA_TYPE* DataTypeTable34[8] =
{
    &DataTypeVar0, // 0
    &DataTypeVar1, // 1
    &DataTypeVar2, // 2
    &DataTypeVar3, // 3
    &DataTypeVar4, // 4
    &DataTypeVar5, // 5
    &DataTypeVar6, // 6
    &DataTypeVar7 // 7
}; // DataTypeTable34[]
const GED_DATA_TYPE* DataTypeTable35[8] =
{
    &DataTypeVar0, // 0
    NULL, // 1
    NULL, // 2
    NULL, // 3
    NULL, // 4
    NULL, // 5
    NULL, // 6
    NULL // 7
}; // DataTypeTable35[]
const GED_DATA_TYPE* DataTypeTable36[8] =
{
    NULL, // 0
    &DataTypeVar1, // 1
    NULL, // 2
    NULL, // 3
    NULL, // 4
    NULL, // 5
    NULL, // 6
    NULL // 7
}; // DataTypeTable36[]
const GED_DATA_TYPE* DataTypeTable37[8] =
{
    &DataTypeVar0, // 0
    &DataTypeVar1, // 1
    &DataTypeVar2, // 2
    &DataTypeVar3, // 3
    &DataTypeVar11, // 4
    &DataTypeVar12, // 5
    &DataTypeVar13, // 6
    &DataTypeVar7 // 7
}; // DataTypeTable37[]
const GED_DATA_TYPE* DataTypeTable38[4] =
{
    &DataTypeVar7, // 0
    &DataTypeVar1, // 1
    &DataTypeVar0, // 2
    &DataTypeVar6 // 3
}; // DataTypeTable38[]
static GED_DEBUG_CTRL DebugCtrlVar0 = (GED_DEBUG_CTRL)0;
static GED_DEBUG_CTRL DebugCtrlVar1 = (GED_DEBUG_CTRL)1;
const GED_DEBUG_CTRL* DebugCtrlTable0[2] =
{
    &DebugCtrlVar0, // 0
    &DebugCtrlVar1 // 1
}; // DebugCtrlTable0[]
static GED_DEP_CTRL DepCtrlVar0 = (GED_DEP_CTRL)0;
static GED_DEP_CTRL DepCtrlVar1 = (GED_DEP_CTRL)1;
static GED_DEP_CTRL DepCtrlVar2 = (GED_DEP_CTRL)2;
static GED_DEP_CTRL DepCtrlVar3 = (GED_DEP_CTRL)3;
const GED_DEP_CTRL* DepCtrlTable0[4] =
{
    &DepCtrlVar0, // 0
    &DepCtrlVar1, // 1
    &DepCtrlVar2, // 2
    &DepCtrlVar3 // 3
}; // DepCtrlTable0[]
static GED_DP_ADDR_SIZE DpAddrSizeVar0 = (GED_DP_ADDR_SIZE)0;
static GED_DP_ADDR_SIZE DpAddrSizeVar1 = (GED_DP_ADDR_SIZE)1;
static GED_DP_ADDR_SIZE DpAddrSizeVar2 = (GED_DP_ADDR_SIZE)2;
const GED_DP_ADDR_SIZE* DpAddrSizeTable0[4] =
{
    NULL, // 0
    &DpAddrSizeVar0, // 1
    &DpAddrSizeVar1, // 2
    &DpAddrSizeVar2 // 3
}; // DpAddrSizeTable0[]
static GED_DP_ADDR_SURFACE_TYPE DpAddrSurfaceTypeVar0 = (GED_DP_ADDR_SURFACE_TYPE)0;
static GED_DP_ADDR_SURFACE_TYPE DpAddrSurfaceTypeVar1 = (GED_DP_ADDR_SURFACE_TYPE)1;
static GED_DP_ADDR_SURFACE_TYPE DpAddrSurfaceTypeVar2 = (GED_DP_ADDR_SURFACE_TYPE)2;
static GED_DP_ADDR_SURFACE_TYPE DpAddrSurfaceTypeVar3 = (GED_DP_ADDR_SURFACE_TYPE)3;
const GED_DP_ADDR_SURFACE_TYPE* DpAddrSurfaceTypeTable0[4] =
{
    &DpAddrSurfaceTypeVar0, // 0
    &DpAddrSurfaceTypeVar1, // 1
    &DpAddrSurfaceTypeVar2, // 2
    &DpAddrSurfaceTypeVar3 // 3
}; // DpAddrSurfaceTypeTable0[]
static GED_DP_DATA_SIZE DpDataSizeVar0 = (GED_DP_DATA_SIZE)0;
static GED_DP_DATA_SIZE DpDataSizeVar1 = (GED_DP_DATA_SIZE)1;
static GED_DP_DATA_SIZE DpDataSizeVar2 = (GED_DP_DATA_SIZE)2;
static GED_DP_DATA_SIZE DpDataSizeVar3 = (GED_DP_DATA_SIZE)3;
static GED_DP_DATA_SIZE DpDataSizeVar4 = (GED_DP_DATA_SIZE)4;
static GED_DP_DATA_SIZE DpDataSizeVar5 = (GED_DP_DATA_SIZE)5;
static GED_DP_DATA_SIZE DpDataSizeVar6 = (GED_DP_DATA_SIZE)6;
const GED_DP_DATA_SIZE* DpDataSizeTable0[8] =
{
    &DpDataSizeVar0, // 0
    &DpDataSizeVar1, // 1
    &DpDataSizeVar2, // 2
    &DpDataSizeVar3, // 3
    &DpDataSizeVar4, // 4
    &DpDataSizeVar5, // 5
    &DpDataSizeVar6, // 6
    NULL // 7
}; // DpDataSizeTable0[]
static GED_DP_FENCE_SCOPE DpFenceScopeVar0 = (GED_DP_FENCE_SCOPE)0;
static GED_DP_FENCE_SCOPE DpFenceScopeVar1 = (GED_DP_FENCE_SCOPE)1;
static GED_DP_FENCE_SCOPE DpFenceScopeVar2 = (GED_DP_FENCE_SCOPE)2;
static GED_DP_FENCE_SCOPE DpFenceScopeVar3 = (GED_DP_FENCE_SCOPE)3;
static GED_DP_FENCE_SCOPE DpFenceScopeVar4 = (GED_DP_FENCE_SCOPE)4;
static GED_DP_FENCE_SCOPE DpFenceScopeVar5 = (GED_DP_FENCE_SCOPE)5;
static GED_DP_FENCE_SCOPE DpFenceScopeVar6 = (GED_DP_FENCE_SCOPE)6;
const GED_DP_FENCE_SCOPE* DpFenceScopeTable0[8] =
{
    &DpFenceScopeVar0, // 0
    &DpFenceScopeVar1, // 1
    &DpFenceScopeVar2, // 2
    &DpFenceScopeVar3, // 3
    &DpFenceScopeVar4, // 4
    NULL, // 5
    NULL, // 6
    NULL // 7
}; // DpFenceScopeTable0[]
const GED_DP_FENCE_SCOPE* DpFenceScopeTable1[8] =
{
    &DpFenceScopeVar0, // 0
    &DpFenceScopeVar1, // 1
    &DpFenceScopeVar2, // 2
    &DpFenceScopeVar3, // 3
    &DpFenceScopeVar4, // 4
    &DpFenceScopeVar5, // 5
    &DpFenceScopeVar6, // 6
    NULL // 7
}; // DpFenceScopeTable1[]
static GED_DP_FLUSH_TYPE DpFlushTypeVar0 = (GED_DP_FLUSH_TYPE)0;
static GED_DP_FLUSH_TYPE DpFlushTypeVar1 = (GED_DP_FLUSH_TYPE)1;
static GED_DP_FLUSH_TYPE DpFlushTypeVar2 = (GED_DP_FLUSH_TYPE)2;
static GED_DP_FLUSH_TYPE DpFlushTypeVar3 = (GED_DP_FLUSH_TYPE)3;
static GED_DP_FLUSH_TYPE DpFlushTypeVar4 = (GED_DP_FLUSH_TYPE)4;
static GED_DP_FLUSH_TYPE DpFlushTypeVar5 = (GED_DP_FLUSH_TYPE)5;
const GED_DP_FLUSH_TYPE* DpFlushTypeTable0[8] =
{
    NULL, // 0
    &DpFlushTypeVar0, // 1
    &DpFlushTypeVar1, // 2
    &DpFlushTypeVar2, // 3
    &DpFlushTypeVar3, // 4
    &DpFlushTypeVar4, // 5
    &DpFlushTypeVar5, // 6
    NULL // 7
}; // DpFlushTypeTable0[]
const GED_DP_FLUSH_TYPE* DpFlushTypeTable1[8] =
{
    &DpFlushTypeVar5, // 0
    &DpFlushTypeVar0, // 1
    &DpFlushTypeVar1, // 2
    NULL, // 3
    NULL, // 4
    NULL, // 5
    NULL, // 6
    NULL // 7
}; // DpFlushTypeTable1[]
static GED_DP_OPCODE DpOpcodeVar0 = (GED_DP_OPCODE)0;
static GED_DP_OPCODE DpOpcodeVar1 = (GED_DP_OPCODE)1;
static GED_DP_OPCODE DpOpcodeVar2 = (GED_DP_OPCODE)2;
static GED_DP_OPCODE DpOpcodeVar3 = (GED_DP_OPCODE)3;
static GED_DP_OPCODE DpOpcodeVar4 = (GED_DP_OPCODE)4;
static GED_DP_OPCODE DpOpcodeVar5 = (GED_DP_OPCODE)5;
static GED_DP_OPCODE DpOpcodeVar6 = (GED_DP_OPCODE)6;
static GED_DP_OPCODE DpOpcodeVar7 = (GED_DP_OPCODE)7;
static GED_DP_OPCODE DpOpcodeVar8 = (GED_DP_OPCODE)8;
static GED_DP_OPCODE DpOpcodeVar9 = (GED_DP_OPCODE)9;
static GED_DP_OPCODE DpOpcodeVar10 = (GED_DP_OPCODE)10;
static GED_DP_OPCODE DpOpcodeVar11 = (GED_DP_OPCODE)11;
static GED_DP_OPCODE DpOpcodeVar12 = (GED_DP_OPCODE)12;
static GED_DP_OPCODE DpOpcodeVar13 = (GED_DP_OPCODE)13;
static GED_DP_OPCODE DpOpcodeVar14 = (GED_DP_OPCODE)14;
static GED_DP_OPCODE DpOpcodeVar15 = (GED_DP_OPCODE)15;
static GED_DP_OPCODE DpOpcodeVar16 = (GED_DP_OPCODE)16;
static GED_DP_OPCODE DpOpcodeVar17 = (GED_DP_OPCODE)17;
static GED_DP_OPCODE DpOpcodeVar18 = (GED_DP_OPCODE)18;
static GED_DP_OPCODE DpOpcodeVar19 = (GED_DP_OPCODE)19;
static GED_DP_OPCODE DpOpcodeVar20 = (GED_DP_OPCODE)20;
static GED_DP_OPCODE DpOpcodeVar21 = (GED_DP_OPCODE)21;
static GED_DP_OPCODE DpOpcodeVar22 = (GED_DP_OPCODE)22;
static GED_DP_OPCODE DpOpcodeVar23 = (GED_DP_OPCODE)23;
static GED_DP_OPCODE DpOpcodeVar24 = (GED_DP_OPCODE)24;
static GED_DP_OPCODE DpOpcodeVar25 = (GED_DP_OPCODE)25;
static GED_DP_OPCODE DpOpcodeVar26 = (GED_DP_OPCODE)26;
const GED_DP_OPCODE* DpOpcodeTable0[64] =
{
    &DpOpcodeVar0, // 0
    NULL, // 1
    &DpOpcodeVar1, // 2
    NULL, // 3
    &DpOpcodeVar2, // 4
    NULL, // 5
    &DpOpcodeVar3, // 6
    NULL, // 7
    &DpOpcodeVar4, // 8
    &DpOpcodeVar5, // 9
    &DpOpcodeVar6, // 10
    &DpOpcodeVar7, // 11
    &DpOpcodeVar8, // 12
    &DpOpcodeVar9, // 13
    &DpOpcodeVar10, // 14
    &DpOpcodeVar11, // 15
    &DpOpcodeVar12, // 16
    &DpOpcodeVar13, // 17
    &DpOpcodeVar14, // 18
    &DpOpcodeVar15, // 19
    &DpOpcodeVar16, // 20
    &DpOpcodeVar17, // 21
    &DpOpcodeVar18, // 22
    &DpOpcodeVar19, // 23
    &DpOpcodeVar20, // 24
    &DpOpcodeVar21, // 25
    &DpOpcodeVar22, // 26
    NULL, // 27
    &DpOpcodeVar23, // 28
    NULL, // 29
    NULL, // 30
    &DpOpcodeVar24, // 31
    NULL, // 32
    NULL, // 33
    NULL, // 34
    NULL, // 35
    NULL, // 36
    NULL, // 37
    NULL, // 38
    NULL, // 39
    NULL, // 40
    NULL, // 41
    NULL, // 42
    NULL, // 43
    NULL, // 44
    NULL, // 45
    NULL, // 46
    NULL, // 47
    NULL, // 48
    NULL, // 49
    NULL, // 50
    NULL, // 51
    NULL, // 52
    NULL, // 53
    NULL, // 54
    NULL, // 55
    NULL, // 56
    NULL, // 57
    NULL, // 58
    NULL, // 59
    NULL, // 60
    NULL, // 61
    NULL, // 62
    NULL // 63
}; // DpOpcodeTable0[]
const GED_DP_OPCODE* DpOpcodeTable1[64] =
{
    &DpOpcodeVar0, // 0
    NULL, // 1
    &DpOpcodeVar1, // 2
    &DpOpcodeVar25, // 3
    &DpOpcodeVar2, // 4
    NULL, // 5
    &DpOpcodeVar3, // 6
    &DpOpcodeVar26, // 7
    &DpOpcodeVar4, // 8
    &DpOpcodeVar5, // 9
    &DpOpcodeVar6, // 10
    &DpOpcodeVar7, // 11
    &DpOpcodeVar8, // 12
    &DpOpcodeVar9, // 13
    &DpOpcodeVar10, // 14
    &DpOpcodeVar11, // 15
    &DpOpcodeVar12, // 16
    &DpOpcodeVar13, // 17
    &DpOpcodeVar14, // 18
    &DpOpcodeVar15, // 19
    &DpOpcodeVar16, // 20
    &DpOpcodeVar17, // 21
    &DpOpcodeVar18, // 22
    &DpOpcodeVar19, // 23
    &DpOpcodeVar20, // 24
    &DpOpcodeVar21, // 25
    &DpOpcodeVar22, // 26
    NULL, // 27
    &DpOpcodeVar23, // 28
    NULL, // 29
    NULL, // 30
    &DpOpcodeVar24, // 31
    NULL, // 32
    NULL, // 33
    NULL, // 34
    NULL, // 35
    NULL, // 36
    NULL, // 37
    NULL, // 38
    NULL, // 39
    NULL, // 40
    NULL, // 41
    NULL, // 42
    NULL, // 43
    NULL, // 44
    NULL, // 45
    NULL, // 46
    NULL, // 47
    NULL, // 48
    NULL, // 49
    NULL, // 50
    NULL, // 51
    NULL, // 52
    NULL, // 53
    NULL, // 54
    NULL, // 55
    NULL, // 56
    NULL, // 57
    NULL, // 58
    NULL, // 59
    NULL, // 60
    NULL, // 61
    NULL, // 62
    NULL // 63
}; // DpOpcodeTable1[]
static GED_DP_TRANSPOSE DpTransposeVar0 = (GED_DP_TRANSPOSE)0;
static GED_DP_TRANSPOSE DpTransposeVar1 = (GED_DP_TRANSPOSE)1;
const GED_DP_TRANSPOSE* DpTransposeTable0[2] =
{
    &DpTransposeVar0, // 0
    &DpTransposeVar1 // 1
}; // DpTransposeTable0[]
static GED_DP_VECT_SIZE DpVectSizeVar0 = (GED_DP_VECT_SIZE)0;
static GED_DP_VECT_SIZE DpVectSizeVar1 = (GED_DP_VECT_SIZE)1;
static GED_DP_VECT_SIZE DpVectSizeVar2 = (GED_DP_VECT_SIZE)2;
static GED_DP_VECT_SIZE DpVectSizeVar3 = (GED_DP_VECT_SIZE)3;
static GED_DP_VECT_SIZE DpVectSizeVar4 = (GED_DP_VECT_SIZE)4;
static GED_DP_VECT_SIZE DpVectSizeVar5 = (GED_DP_VECT_SIZE)5;
static GED_DP_VECT_SIZE DpVectSizeVar6 = (GED_DP_VECT_SIZE)6;
static GED_DP_VECT_SIZE DpVectSizeVar7 = (GED_DP_VECT_SIZE)7;
const GED_DP_VECT_SIZE* DpVectSizeTable0[8] =
{
    &DpVectSizeVar0, // 0
    &DpVectSizeVar1, // 1
    &DpVectSizeVar2, // 2
    &DpVectSizeVar3, // 3
    &DpVectSizeVar4, // 4
    &DpVectSizeVar5, // 5
    &DpVectSizeVar6, // 6
    &DpVectSizeVar7 // 7
}; // DpVectSizeTable0[]
static GED_DST_CHAN_EN DstChanEnVar0 = (GED_DST_CHAN_EN)0;
static GED_DST_CHAN_EN DstChanEnVar1 = (GED_DST_CHAN_EN)1;
static GED_DST_CHAN_EN DstChanEnVar2 = (GED_DST_CHAN_EN)2;
static GED_DST_CHAN_EN DstChanEnVar3 = (GED_DST_CHAN_EN)3;
static GED_DST_CHAN_EN DstChanEnVar4 = (GED_DST_CHAN_EN)4;
static GED_DST_CHAN_EN DstChanEnVar5 = (GED_DST_CHAN_EN)5;
static GED_DST_CHAN_EN DstChanEnVar6 = (GED_DST_CHAN_EN)6;
static GED_DST_CHAN_EN DstChanEnVar7 = (GED_DST_CHAN_EN)7;
static GED_DST_CHAN_EN DstChanEnVar8 = (GED_DST_CHAN_EN)8;
static GED_DST_CHAN_EN DstChanEnVar9 = (GED_DST_CHAN_EN)9;
static GED_DST_CHAN_EN DstChanEnVar10 = (GED_DST_CHAN_EN)10;
static GED_DST_CHAN_EN DstChanEnVar11 = (GED_DST_CHAN_EN)11;
static GED_DST_CHAN_EN DstChanEnVar12 = (GED_DST_CHAN_EN)12;
static GED_DST_CHAN_EN DstChanEnVar13 = (GED_DST_CHAN_EN)13;
static GED_DST_CHAN_EN DstChanEnVar14 = (GED_DST_CHAN_EN)14;
static GED_DST_CHAN_EN DstChanEnVar15 = (GED_DST_CHAN_EN)15;
const GED_DST_CHAN_EN* DstChanEnTable0[16] =
{
    &DstChanEnVar0, // 0
    &DstChanEnVar1, // 1
    &DstChanEnVar2, // 2
    &DstChanEnVar3, // 3
    &DstChanEnVar4, // 4
    &DstChanEnVar5, // 5
    &DstChanEnVar6, // 6
    &DstChanEnVar7, // 7
    &DstChanEnVar8, // 8
    &DstChanEnVar9, // 9
    &DstChanEnVar10, // 10
    &DstChanEnVar11, // 11
    &DstChanEnVar12, // 12
    &DstChanEnVar13, // 13
    &DstChanEnVar14, // 14
    &DstChanEnVar15 // 15
}; // DstChanEnTable0[]
static GED_EOT EOTVar0 = (GED_EOT)0;
static GED_EOT EOTVar1 = (GED_EOT)1;
const GED_EOT* EOTTable0[2] =
{
    &EOTVar0, // 0
    &EOTVar1 // 1
}; // EOTTable0[]
static GED_EXEC_MASK_OFFSET_CTRL ExecMaskOffsetCtrlVar0 = (GED_EXEC_MASK_OFFSET_CTRL)0;
static GED_EXEC_MASK_OFFSET_CTRL ExecMaskOffsetCtrlVar1 = (GED_EXEC_MASK_OFFSET_CTRL)1;
static GED_EXEC_MASK_OFFSET_CTRL ExecMaskOffsetCtrlVar2 = (GED_EXEC_MASK_OFFSET_CTRL)2;
static GED_EXEC_MASK_OFFSET_CTRL ExecMaskOffsetCtrlVar3 = (GED_EXEC_MASK_OFFSET_CTRL)3;
static GED_EXEC_MASK_OFFSET_CTRL ExecMaskOffsetCtrlVar4 = (GED_EXEC_MASK_OFFSET_CTRL)4;
static GED_EXEC_MASK_OFFSET_CTRL ExecMaskOffsetCtrlVar5 = (GED_EXEC_MASK_OFFSET_CTRL)5;
static GED_EXEC_MASK_OFFSET_CTRL ExecMaskOffsetCtrlVar6 = (GED_EXEC_MASK_OFFSET_CTRL)6;
static GED_EXEC_MASK_OFFSET_CTRL ExecMaskOffsetCtrlVar7 = (GED_EXEC_MASK_OFFSET_CTRL)7;
static GED_EXEC_MASK_OFFSET_CTRL ExecMaskOffsetCtrlVar8 = (GED_EXEC_MASK_OFFSET_CTRL)8;
static GED_EXEC_MASK_OFFSET_CTRL ExecMaskOffsetCtrlVar9 = (GED_EXEC_MASK_OFFSET_CTRL)9;
static GED_EXEC_MASK_OFFSET_CTRL ExecMaskOffsetCtrlVar10 = (GED_EXEC_MASK_OFFSET_CTRL)10;
static GED_EXEC_MASK_OFFSET_CTRL ExecMaskOffsetCtrlVar11 = (GED_EXEC_MASK_OFFSET_CTRL)11;
static GED_EXEC_MASK_OFFSET_CTRL ExecMaskOffsetCtrlVar12 = (GED_EXEC_MASK_OFFSET_CTRL)12;
static GED_EXEC_MASK_OFFSET_CTRL ExecMaskOffsetCtrlVar13 = (GED_EXEC_MASK_OFFSET_CTRL)13;
const GED_EXEC_MASK_OFFSET_CTRL* ExecMaskOffsetCtrlTable0[8] =
{
    &ExecMaskOffsetCtrlVar0, // 0
    &ExecMaskOffsetCtrlVar1, // 1
    &ExecMaskOffsetCtrlVar2, // 2
    &ExecMaskOffsetCtrlVar3, // 3
    &ExecMaskOffsetCtrlVar4, // 4
    &ExecMaskOffsetCtrlVar5, // 5
    &ExecMaskOffsetCtrlVar6, // 6
    &ExecMaskOffsetCtrlVar7 // 7
}; // ExecMaskOffsetCtrlTable0[]
const GED_EXEC_MASK_OFFSET_CTRL* ExecMaskOffsetCtrlTable1[8] =
{
    &ExecMaskOffsetCtrlVar8, // 0
    NULL, // 1
    &ExecMaskOffsetCtrlVar9, // 2
    NULL, // 3
    &ExecMaskOffsetCtrlVar10, // 4
    NULL, // 5
    &ExecMaskOffsetCtrlVar11, // 6
    NULL // 7
}; // ExecMaskOffsetCtrlTable1[]
const GED_EXEC_MASK_OFFSET_CTRL* ExecMaskOffsetCtrlTable2[8] =
{
    &ExecMaskOffsetCtrlVar12, // 0
    NULL, // 1
    NULL, // 2
    NULL, // 3
    &ExecMaskOffsetCtrlVar13, // 4
    NULL, // 5
    NULL, // 6
    NULL // 7
}; // ExecMaskOffsetCtrlTable2[]
static GED_EXECUTION_DATA_TYPE ExecutionDataTypeVar0 = (GED_EXECUTION_DATA_TYPE)0;
static GED_EXECUTION_DATA_TYPE ExecutionDataTypeVar1 = (GED_EXECUTION_DATA_TYPE)1;
const GED_EXECUTION_DATA_TYPE* ExecutionDataTypeTable0[2] =
{
    &ExecutionDataTypeVar0, // 0
    &ExecutionDataTypeVar1 // 1
}; // ExecutionDataTypeTable0[]
static GED_FUSION_CTRL FusionCtrlVar0 = (GED_FUSION_CTRL)0;
static GED_FUSION_CTRL FusionCtrlVar1 = (GED_FUSION_CTRL)1;
const GED_FUSION_CTRL* FusionCtrlTable0[2] =
{
    &FusionCtrlVar0, // 0
    &FusionCtrlVar1 // 1
}; // FusionCtrlTable0[]
static GED_HEADER_PRESENT HeaderPresentVar0 = (GED_HEADER_PRESENT)0;
static GED_HEADER_PRESENT HeaderPresentVar1 = (GED_HEADER_PRESENT)1;
const GED_HEADER_PRESENT* HeaderPresentTable0[2] =
{
    &HeaderPresentVar0, // 0
    &HeaderPresentVar1 // 1
}; // HeaderPresentTable0[]
static GED_MASK_CTRL MaskCtrlVar0 = (GED_MASK_CTRL)0;
static GED_MASK_CTRL MaskCtrlVar1 = (GED_MASK_CTRL)1;
const GED_MASK_CTRL* MaskCtrlTable0[2] =
{
    &MaskCtrlVar0, // 0
    &MaskCtrlVar1 // 1
}; // MaskCtrlTable0[]
const GED_MASK_CTRL* MaskCtrlTable1[2] =
{
    NULL, // 0
    &MaskCtrlVar1 // 1
}; // MaskCtrlTable1[]
static GED_MATH_FC MathFCVar0 = (GED_MATH_FC)0;
static GED_MATH_FC MathFCVar1 = (GED_MATH_FC)1;
static GED_MATH_FC MathFCVar2 = (GED_MATH_FC)2;
static GED_MATH_FC MathFCVar3 = (GED_MATH_FC)3;
static GED_MATH_FC MathFCVar4 = (GED_MATH_FC)4;
static GED_MATH_FC MathFCVar5 = (GED_MATH_FC)5;
static GED_MATH_FC MathFCVar6 = (GED_MATH_FC)6;
static GED_MATH_FC MathFCVar7 = (GED_MATH_FC)7;
static GED_MATH_FC MathFCVar8 = (GED_MATH_FC)8;
static GED_MATH_FC MathFCVar9 = (GED_MATH_FC)9;
static GED_MATH_FC MathFCVar10 = (GED_MATH_FC)10;
static GED_MATH_FC MathFCVar11 = (GED_MATH_FC)11;
static GED_MATH_FC MathFCVar12 = (GED_MATH_FC)12;
static GED_MATH_FC MathFCVar13 = (GED_MATH_FC)13;
const GED_MATH_FC* MathFCTable0[16] =
{
    NULL, // 0
    &MathFCVar0, // 1
    &MathFCVar1, // 2
    &MathFCVar2, // 3
    &MathFCVar3, // 4
    &MathFCVar4, // 5
    &MathFCVar5, // 6
    &MathFCVar6, // 7
    NULL, // 8
    &MathFCVar7, // 9
    &MathFCVar8, // 10
    &MathFCVar9, // 11
    &MathFCVar10, // 12
    &MathFCVar11, // 13
    &MathFCVar12, // 14
    &MathFCVar13 // 15
}; // MathFCTable0[]
const GED_MATH_FC* MathFCTable1[16] =
{
    NULL, // 0
    &MathFCVar0, // 1
    &MathFCVar1, // 2
    &MathFCVar2, // 3
    &MathFCVar3, // 4
    &MathFCVar4, // 5
    &MathFCVar5, // 6
    &MathFCVar6, // 7
    NULL, // 8
    NULL, // 9
    NULL, // 10
    &MathFCVar9, // 11
    &MathFCVar10, // 12
    &MathFCVar11, // 13
    &MathFCVar12, // 14
    &MathFCVar13 // 15
}; // MathFCTable1[]
const GED_MATH_FC* MathFCTable2[16] =
{
    NULL, // 0
    &MathFCVar0, // 1
    &MathFCVar1, // 2
    &MathFCVar2, // 3
    &MathFCVar3, // 4
    &MathFCVar4, // 5
    &MathFCVar5, // 6
    &MathFCVar6, // 7
    NULL, // 8
    NULL, // 9
    NULL, // 10
    NULL, // 11
    NULL, // 12
    NULL, // 13
    &MathFCVar12, // 14
    &MathFCVar13 // 15
}; // MathFCTable2[]
const GED_MATH_FC* MathFCTable3[16] =
{
    NULL, // 0
    &MathFCVar0, // 1
    &MathFCVar1, // 2
    &MathFCVar2, // 3
    &MathFCVar3, // 4
    &MathFCVar4, // 5
    &MathFCVar5, // 6
    &MathFCVar6, // 7
    NULL, // 8
    &MathFCVar7, // 9
    &MathFCVar8, // 10
    &MathFCVar9, // 11
    &MathFCVar10, // 12
    &MathFCVar11, // 13
    NULL, // 14
    NULL // 15
}; // MathFCTable3[]
static GED_MATH_MACRO_EXT MathMacroExtVar0 = (GED_MATH_MACRO_EXT)0;
static GED_MATH_MACRO_EXT MathMacroExtVar1 = (GED_MATH_MACRO_EXT)1;
static GED_MATH_MACRO_EXT MathMacroExtVar2 = (GED_MATH_MACRO_EXT)2;
static GED_MATH_MACRO_EXT MathMacroExtVar3 = (GED_MATH_MACRO_EXT)3;
static GED_MATH_MACRO_EXT MathMacroExtVar4 = (GED_MATH_MACRO_EXT)4;
static GED_MATH_MACRO_EXT MathMacroExtVar5 = (GED_MATH_MACRO_EXT)5;
static GED_MATH_MACRO_EXT MathMacroExtVar6 = (GED_MATH_MACRO_EXT)6;
static GED_MATH_MACRO_EXT MathMacroExtVar7 = (GED_MATH_MACRO_EXT)7;
static GED_MATH_MACRO_EXT MathMacroExtVar8 = (GED_MATH_MACRO_EXT)8;
const GED_MATH_MACRO_EXT* MathMacroExtTable0[16] =
{
    &MathMacroExtVar0, // 0
    &MathMacroExtVar1, // 1
    &MathMacroExtVar2, // 2
    &MathMacroExtVar3, // 3
    &MathMacroExtVar4, // 4
    &MathMacroExtVar5, // 5
    &MathMacroExtVar6, // 6
    &MathMacroExtVar7, // 7
    &MathMacroExtVar8, // 8
    NULL, // 9
    NULL, // 10
    NULL, // 11
    NULL, // 12
    NULL, // 13
    NULL, // 14
    NULL // 15
}; // MathMacroExtTable0[]
static GED_MESSAGE_TYPE MessageTypeVar0 = (GED_MESSAGE_TYPE)0;
static GED_MESSAGE_TYPE MessageTypeVar1 = (GED_MESSAGE_TYPE)1;
static GED_MESSAGE_TYPE MessageTypeVar2 = (GED_MESSAGE_TYPE)2;
static GED_MESSAGE_TYPE MessageTypeVar3 = (GED_MESSAGE_TYPE)3;
static GED_MESSAGE_TYPE MessageTypeVar4 = (GED_MESSAGE_TYPE)4;
static GED_MESSAGE_TYPE MessageTypeVar5 = (GED_MESSAGE_TYPE)5;
static GED_MESSAGE_TYPE MessageTypeVar6 = (GED_MESSAGE_TYPE)6;
static GED_MESSAGE_TYPE MessageTypeVar7 = (GED_MESSAGE_TYPE)7;
static GED_MESSAGE_TYPE MessageTypeVar8 = (GED_MESSAGE_TYPE)8;
static GED_MESSAGE_TYPE MessageTypeVar9 = (GED_MESSAGE_TYPE)9;
static GED_MESSAGE_TYPE MessageTypeVar10 = (GED_MESSAGE_TYPE)10;
static GED_MESSAGE_TYPE MessageTypeVar11 = (GED_MESSAGE_TYPE)11;
static GED_MESSAGE_TYPE MessageTypeVar12 = (GED_MESSAGE_TYPE)12;
static GED_MESSAGE_TYPE MessageTypeVar13 = (GED_MESSAGE_TYPE)13;
static GED_MESSAGE_TYPE MessageTypeVar14 = (GED_MESSAGE_TYPE)14;
static GED_MESSAGE_TYPE MessageTypeVar15 = (GED_MESSAGE_TYPE)15;
static GED_MESSAGE_TYPE MessageTypeVar16 = (GED_MESSAGE_TYPE)16;
static GED_MESSAGE_TYPE MessageTypeVar17 = (GED_MESSAGE_TYPE)17;
static GED_MESSAGE_TYPE MessageTypeVar18 = (GED_MESSAGE_TYPE)18;
static GED_MESSAGE_TYPE MessageTypeVar19 = (GED_MESSAGE_TYPE)19;
static GED_MESSAGE_TYPE MessageTypeVar20 = (GED_MESSAGE_TYPE)20;
static GED_MESSAGE_TYPE MessageTypeVar21 = (GED_MESSAGE_TYPE)21;
static GED_MESSAGE_TYPE MessageTypeVar22 = (GED_MESSAGE_TYPE)22;
static GED_MESSAGE_TYPE MessageTypeVar23 = (GED_MESSAGE_TYPE)23;
static GED_MESSAGE_TYPE MessageTypeVar24 = (GED_MESSAGE_TYPE)24;
static GED_MESSAGE_TYPE MessageTypeVar25 = (GED_MESSAGE_TYPE)25;
static GED_MESSAGE_TYPE MessageTypeVar26 = (GED_MESSAGE_TYPE)26;
static GED_MESSAGE_TYPE MessageTypeVar27 = (GED_MESSAGE_TYPE)27;
static GED_MESSAGE_TYPE MessageTypeVar28 = (GED_MESSAGE_TYPE)28;
static GED_MESSAGE_TYPE MessageTypeVar29 = (GED_MESSAGE_TYPE)29;
static GED_MESSAGE_TYPE MessageTypeVar30 = (GED_MESSAGE_TYPE)30;
static GED_MESSAGE_TYPE MessageTypeVar31 = (GED_MESSAGE_TYPE)31;
static GED_MESSAGE_TYPE MessageTypeVar32 = (GED_MESSAGE_TYPE)32;
static GED_MESSAGE_TYPE MessageTypeVar33 = (GED_MESSAGE_TYPE)33;
static GED_MESSAGE_TYPE MessageTypeVar34 = (GED_MESSAGE_TYPE)34;
static GED_MESSAGE_TYPE MessageTypeVar35 = (GED_MESSAGE_TYPE)35;
static GED_MESSAGE_TYPE MessageTypeVar36 = (GED_MESSAGE_TYPE)36;
static GED_MESSAGE_TYPE MessageTypeVar37 = (GED_MESSAGE_TYPE)37;
static GED_MESSAGE_TYPE MessageTypeVar38 = (GED_MESSAGE_TYPE)38;
static GED_MESSAGE_TYPE MessageTypeVar39 = (GED_MESSAGE_TYPE)39;
static GED_MESSAGE_TYPE MessageTypeVar40 = (GED_MESSAGE_TYPE)40;
static GED_MESSAGE_TYPE MessageTypeVar41 = (GED_MESSAGE_TYPE)41;
static GED_MESSAGE_TYPE MessageTypeVar42 = (GED_MESSAGE_TYPE)42;
static GED_MESSAGE_TYPE MessageTypeVar43 = (GED_MESSAGE_TYPE)43;
static GED_MESSAGE_TYPE MessageTypeVar44 = (GED_MESSAGE_TYPE)44;
static GED_MESSAGE_TYPE MessageTypeVar45 = (GED_MESSAGE_TYPE)45;
static GED_MESSAGE_TYPE MessageTypeVar46 = (GED_MESSAGE_TYPE)46;
static GED_MESSAGE_TYPE MessageTypeVar47 = (GED_MESSAGE_TYPE)47;
static GED_MESSAGE_TYPE MessageTypeVar48 = (GED_MESSAGE_TYPE)48;
static GED_MESSAGE_TYPE MessageTypeVar49 = (GED_MESSAGE_TYPE)49;
static GED_MESSAGE_TYPE MessageTypeVar50 = (GED_MESSAGE_TYPE)50;
static GED_MESSAGE_TYPE MessageTypeVar51 = (GED_MESSAGE_TYPE)51;
static GED_MESSAGE_TYPE MessageTypeVar52 = (GED_MESSAGE_TYPE)52;
static GED_MESSAGE_TYPE MessageTypeVar53 = (GED_MESSAGE_TYPE)53;
static GED_MESSAGE_TYPE MessageTypeVar54 = (GED_MESSAGE_TYPE)54;
static GED_MESSAGE_TYPE MessageTypeVar55 = (GED_MESSAGE_TYPE)55;
static GED_MESSAGE_TYPE MessageTypeVar56 = (GED_MESSAGE_TYPE)56;
static GED_MESSAGE_TYPE MessageTypeVar57 = (GED_MESSAGE_TYPE)57;
static GED_MESSAGE_TYPE MessageTypeVar58 = (GED_MESSAGE_TYPE)58;
static GED_MESSAGE_TYPE MessageTypeVar59 = (GED_MESSAGE_TYPE)59;
static GED_MESSAGE_TYPE MessageTypeVar60 = (GED_MESSAGE_TYPE)60;
static GED_MESSAGE_TYPE MessageTypeVar61 = (GED_MESSAGE_TYPE)61;
static GED_MESSAGE_TYPE MessageTypeVar62 = (GED_MESSAGE_TYPE)62;
static GED_MESSAGE_TYPE MessageTypeVar63 = (GED_MESSAGE_TYPE)63;
static GED_MESSAGE_TYPE MessageTypeVar64 = (GED_MESSAGE_TYPE)64;
static GED_MESSAGE_TYPE MessageTypeVar65 = (GED_MESSAGE_TYPE)65;
static GED_MESSAGE_TYPE MessageTypeVar66 = (GED_MESSAGE_TYPE)66;
static GED_MESSAGE_TYPE MessageTypeVar67 = (GED_MESSAGE_TYPE)67;
static GED_MESSAGE_TYPE MessageTypeVar68 = (GED_MESSAGE_TYPE)68;
static GED_MESSAGE_TYPE MessageTypeVar69 = (GED_MESSAGE_TYPE)69;
static GED_MESSAGE_TYPE MessageTypeVar70 = (GED_MESSAGE_TYPE)70;
static GED_MESSAGE_TYPE MessageTypeVar71 = (GED_MESSAGE_TYPE)71;
static GED_MESSAGE_TYPE MessageTypeVar72 = (GED_MESSAGE_TYPE)72;
static GED_MESSAGE_TYPE MessageTypeVar73 = (GED_MESSAGE_TYPE)73;
static GED_MESSAGE_TYPE MessageTypeVar74 = (GED_MESSAGE_TYPE)74;
static GED_MESSAGE_TYPE MessageTypeVar75 = (GED_MESSAGE_TYPE)75;
static GED_MESSAGE_TYPE MessageTypeVar76 = (GED_MESSAGE_TYPE)76;
const GED_MESSAGE_TYPE* MessageTypeTable0[2] =
{
    &MessageTypeVar0, // 0
    &MessageTypeVar1 // 1
}; // MessageTypeTable0[]
const GED_MESSAGE_TYPE* MessageTypeTable1[16] =
{
    &MessageTypeVar2, // 0
    &MessageTypeVar3, // 1
    &MessageTypeVar4, // 2
    &MessageTypeVar5, // 3
    &MessageTypeVar6, // 4
    NULL, // 5
    NULL, // 6
    &MessageTypeVar7, // 7
    &MessageTypeVar8, // 8
    NULL, // 9
    &MessageTypeVar9, // 10
    &MessageTypeVar10, // 11
    &MessageTypeVar11, // 12
    NULL, // 13
    NULL, // 14
    NULL // 15
}; // MessageTypeTable1[]
const GED_MESSAGE_TYPE* MessageTypeTable2[32] =
{
    &MessageTypeVar12, // 0
    &MessageTypeVar13, // 1
    &MessageTypeVar14, // 2
    &MessageTypeVar15, // 3
    &MessageTypeVar16, // 4
    &MessageTypeVar17, // 5
    &MessageTypeVar18, // 6
    &MessageTypeVar19, // 7
    NULL, // 8
    &MessageTypeVar20, // 9
    &MessageTypeVar21, // 10
    &MessageTypeVar22, // 11
    &MessageTypeVar23, // 12
    &MessageTypeVar24, // 13
    NULL, // 14
    NULL, // 15
    &MessageTypeVar25, // 16
    &MessageTypeVar26, // 17
    &MessageTypeVar27, // 18
    &MessageTypeVar28, // 19
    &MessageTypeVar29, // 20
    &MessageTypeVar30, // 21
    NULL, // 22
    NULL, // 23
    NULL, // 24
    &MessageTypeVar31, // 25
    &MessageTypeVar32, // 26
    NULL, // 27
    NULL, // 28
    NULL, // 29
    NULL, // 30
    NULL // 31
}; // MessageTypeTable2[]
const GED_MESSAGE_TYPE* MessageTypeTable3[32] =
{
    NULL, // 0
    &MessageTypeVar33, // 1
    &MessageTypeVar34, // 2
    &MessageTypeVar35, // 3
    &MessageTypeVar36, // 4
    NULL, // 5
    NULL, // 6
    NULL, // 7
    NULL, // 8
    &MessageTypeVar37, // 9
    &MessageTypeVar38, // 10
    &MessageTypeVar39, // 11
    &MessageTypeVar40, // 12
    NULL, // 13
    NULL, // 14
    NULL, // 15
    NULL, // 16
    NULL, // 17
    NULL, // 18
    NULL, // 19
    NULL, // 20
    NULL, // 21
    NULL, // 22
    NULL, // 23
    NULL, // 24
    NULL, // 25
    NULL, // 26
    NULL, // 27
    NULL, // 28
    NULL, // 29
    NULL, // 30
    NULL // 31
}; // MessageTypeTable3[]
const GED_MESSAGE_TYPE* MessageTypeTable4[32] =
{
    &MessageTypeVar41, // 0
    &MessageTypeVar42, // 1
    &MessageTypeVar43, // 2
    &MessageTypeVar44, // 3
    &MessageTypeVar45, // 4
    NULL, // 5
    NULL, // 6
    NULL, // 7
    NULL, // 8
    &MessageTypeVar46, // 9
    &MessageTypeVar47, // 10
    NULL, // 11
    NULL, // 12
    NULL, // 13
    NULL, // 14
    NULL, // 15
    NULL, // 16
    NULL, // 17
    NULL, // 18
    NULL, // 19
    NULL, // 20
    NULL, // 21
    NULL, // 22
    NULL, // 23
    NULL, // 24
    NULL, // 25
    NULL, // 26
    NULL, // 27
    NULL, // 28
    NULL, // 29
    NULL, // 30
    NULL // 31
}; // MessageTypeTable4[]
const GED_MESSAGE_TYPE* MessageTypeTable5[32] =
{
    NULL, // 0
    NULL, // 1
    NULL, // 2
    NULL, // 3
    NULL, // 4
    NULL, // 5
    NULL, // 6
    NULL, // 7
    NULL, // 8
    NULL, // 9
    NULL, // 10
    NULL, // 11
    &MessageTypeVar48, // 12
    &MessageTypeVar49, // 13
    NULL, // 14
    NULL, // 15
    NULL, // 16
    NULL, // 17
    NULL, // 18
    NULL, // 19
    NULL, // 20
    NULL, // 21
    NULL, // 22
    NULL, // 23
    NULL, // 24
    NULL, // 25
    NULL, // 26
    NULL, // 27
    NULL, // 28
    NULL, // 29
    NULL, // 30
    NULL // 31
}; // MessageTypeTable5[]
const GED_MESSAGE_TYPE* MessageTypeTable6[16] =
{
    &MessageTypeVar2, // 0
    &MessageTypeVar3, // 1
    NULL, // 2
    &MessageTypeVar5, // 3
    &MessageTypeVar6, // 4
    NULL, // 5
    NULL, // 6
    &MessageTypeVar7, // 7
    &MessageTypeVar8, // 8
    NULL, // 9
    NULL, // 10
    &MessageTypeVar10, // 11
    &MessageTypeVar11, // 12
    NULL, // 13
    NULL, // 14
    NULL // 15
}; // MessageTypeTable6[]
const GED_MESSAGE_TYPE* MessageTypeTable7[32] =
{
    NULL, // 0
    &MessageTypeVar13, // 1
    &MessageTypeVar14, // 2
    &MessageTypeVar50, // 3
    &MessageTypeVar16, // 4
    &MessageTypeVar17, // 5
    &MessageTypeVar18, // 6
    &MessageTypeVar51, // 7
    NULL, // 8
    &MessageTypeVar20, // 9
    &MessageTypeVar21, // 10
    &MessageTypeVar22, // 11
    &MessageTypeVar52, // 12
    &MessageTypeVar24, // 13
    NULL, // 14
    NULL, // 15
    &MessageTypeVar25, // 16
    &MessageTypeVar26, // 17
    &MessageTypeVar27, // 18
    &MessageTypeVar53, // 19
    &MessageTypeVar29, // 20
    &MessageTypeVar30, // 21
    NULL, // 22
    NULL, // 23
    NULL, // 24
    &MessageTypeVar31, // 25
    &MessageTypeVar32, // 26
    &MessageTypeVar54, // 27
    &MessageTypeVar55, // 28
    &MessageTypeVar56, // 29
    &MessageTypeVar57, // 30
    NULL // 31
}; // MessageTypeTable7[]
const GED_MESSAGE_TYPE* MessageTypeTable8[32] =
{
    NULL, // 0
    &MessageTypeVar33, // 1
    NULL, // 2
    NULL, // 3
    &MessageTypeVar36, // 4
    NULL, // 5
    NULL, // 6
    NULL, // 7
    NULL, // 8
    &MessageTypeVar37, // 9
    NULL, // 10
    NULL, // 11
    &MessageTypeVar40, // 12
    NULL, // 13
    NULL, // 14
    NULL, // 15
    NULL, // 16
    NULL, // 17
    NULL, // 18
    NULL, // 19
    NULL, // 20
    NULL, // 21
    NULL, // 22
    NULL, // 23
    NULL, // 24
    NULL, // 25
    NULL, // 26
    NULL, // 27
    NULL, // 28
    NULL, // 29
    NULL, // 30
    NULL // 31
}; // MessageTypeTable8[]
const GED_MESSAGE_TYPE* MessageTypeTable9[32] =
{
    &MessageTypeVar41, // 0
    &MessageTypeVar42, // 1
    NULL, // 2
    &MessageTypeVar44, // 3
    &MessageTypeVar45, // 4
    &MessageTypeVar46, // 5
    &MessageTypeVar47, // 6
    NULL, // 7
    NULL, // 8
    NULL, // 9
    NULL, // 10
    NULL, // 11
    NULL, // 12
    NULL, // 13
    NULL, // 14
    NULL, // 15
    NULL, // 16
    NULL, // 17
    NULL, // 18
    NULL, // 19
    NULL, // 20
    NULL, // 21
    NULL, // 22
    NULL, // 23
    NULL, // 24
    NULL, // 25
    NULL, // 26
    NULL, // 27
    NULL, // 28
    NULL, // 29
    NULL, // 30
    NULL // 31
}; // MessageTypeTable9[]
const GED_MESSAGE_TYPE* MessageTypeTable10[32] =
{
    &MessageTypeVar41, // 0
    &MessageTypeVar42, // 1
    NULL, // 2
    &MessageTypeVar44, // 3
    &MessageTypeVar45, // 4
    &MessageTypeVar46, // 5
    &MessageTypeVar47, // 6
    NULL, // 7
    &MessageTypeVar58, // 8
    &MessageTypeVar59, // 9
    NULL, // 10
    NULL, // 11
    &MessageTypeVar60, // 12
    &MessageTypeVar61, // 13
    NULL, // 14
    NULL, // 15
    NULL, // 16
    NULL, // 17
    NULL, // 18
    NULL, // 19
    NULL, // 20
    NULL, // 21
    NULL, // 22
    &MessageTypeVar62, // 23
    &MessageTypeVar63, // 24
    &MessageTypeVar64, // 25
    NULL, // 26
    NULL, // 27
    NULL, // 28
    NULL, // 29
    NULL, // 30
    NULL // 31
}; // MessageTypeTable10[]
const GED_MESSAGE_TYPE* MessageTypeTable11[16] =
{
    &MessageTypeVar2, // 0
    &MessageTypeVar3, // 1
    NULL, // 2
    &MessageTypeVar5, // 3
    &MessageTypeVar6, // 4
    NULL, // 5
    NULL, // 6
    NULL, // 7
    &MessageTypeVar8, // 8
    NULL, // 9
    NULL, // 10
    &MessageTypeVar10, // 11
    &MessageTypeVar11, // 12
    NULL, // 13
    NULL, // 14
    NULL // 15
}; // MessageTypeTable11[]
const GED_MESSAGE_TYPE* MessageTypeTable12[32] =
{
    &MessageTypeVar41, // 0
    &MessageTypeVar42, // 1
    NULL, // 2
    &MessageTypeVar44, // 3
    &MessageTypeVar45, // 4
    &MessageTypeVar46, // 5
    &MessageTypeVar47, // 6
    NULL, // 7
    NULL, // 8
    &MessageTypeVar59, // 9
    NULL, // 10
    NULL, // 11
    &MessageTypeVar60, // 12
    &MessageTypeVar61, // 13
    NULL, // 14
    NULL, // 15
    NULL, // 16
    NULL, // 17
    NULL, // 18
    NULL, // 19
    NULL, // 20
    NULL, // 21
    NULL, // 22
    &MessageTypeVar62, // 23
    NULL, // 24
    NULL, // 25
    NULL, // 26
    NULL, // 27
    NULL, // 28
    NULL, // 29
    NULL, // 30
    &MessageTypeVar65 // 31
}; // MessageTypeTable12[]
const GED_MESSAGE_TYPE* MessageTypeTable13[16] =
{
    NULL, // 0
    &MessageTypeVar45, // 1
    NULL, // 2
    NULL, // 3
    &MessageTypeVar46, // 4
    NULL, // 5
    NULL, // 6
    NULL, // 7
    NULL, // 8
    NULL, // 9
    NULL, // 10
    NULL, // 11
    NULL, // 12
    NULL, // 13
    NULL, // 14
    NULL // 15
}; // MessageTypeTable13[]
const GED_MESSAGE_TYPE* MessageTypeTable14[16] =
{
    NULL, // 0
    NULL, // 1
    NULL, // 2
    NULL, // 3
    &MessageTypeVar66, // 4
    &MessageTypeVar67, // 5
    &MessageTypeVar68, // 6
    &MessageTypeVar69, // 7
    NULL, // 8
    NULL, // 9
    &MessageTypeVar70, // 10
    NULL, // 11
    &MessageTypeVar48, // 12
    &MessageTypeVar71, // 13
    NULL, // 14
    NULL // 15
}; // MessageTypeTable14[]
const GED_MESSAGE_TYPE* MessageTypeTable15[16] =
{
    &MessageTypeVar41, // 0
    &MessageTypeVar42, // 1
    &MessageTypeVar43, // 2
    &MessageTypeVar44, // 3
    NULL, // 4
    NULL, // 5
    NULL, // 6
    NULL, // 7
    NULL, // 8
    NULL, // 9
    NULL, // 10
    NULL, // 11
    NULL, // 12
    NULL, // 13
    NULL, // 14
    NULL // 15
}; // MessageTypeTable15[]
const GED_MESSAGE_TYPE* MessageTypeTable16[16] =
{
    &MessageTypeVar2, // 0
    &MessageTypeVar3, // 1
    &MessageTypeVar4, // 2
    &MessageTypeVar5, // 3
    &MessageTypeVar6, // 4
    &MessageTypeVar72, // 5
    &MessageTypeVar73, // 6
    &MessageTypeVar7, // 7
    &MessageTypeVar8, // 8
    NULL, // 9
    &MessageTypeVar9, // 10
    &MessageTypeVar10, // 11
    &MessageTypeVar11, // 12
    &MessageTypeVar74, // 13
    NULL, // 14
    NULL // 15
}; // MessageTypeTable16[]
const GED_MESSAGE_TYPE* MessageTypeTable17[16] =
{
    &MessageTypeVar47, // 0
    &MessageTypeVar45, // 1
    NULL, // 2
    NULL, // 3
    &MessageTypeVar46, // 4
    NULL, // 5
    NULL, // 6
    NULL, // 7
    NULL, // 8
    NULL, // 9
    NULL, // 10
    NULL, // 11
    NULL, // 12
    NULL, // 13
    NULL, // 14
    NULL // 15
}; // MessageTypeTable17[]
const GED_MESSAGE_TYPE* MessageTypeTable18[16] =
{
    NULL, // 0
    NULL, // 1
    NULL, // 2
    NULL, // 3
    &MessageTypeVar66, // 4
    NULL, // 5
    NULL, // 6
    &MessageTypeVar69, // 7
    NULL, // 8
    NULL, // 9
    &MessageTypeVar70, // 10
    NULL, // 11
    &MessageTypeVar48, // 12
    NULL, // 13
    NULL, // 14
    NULL // 15
}; // MessageTypeTable18[]
const GED_MESSAGE_TYPE* MessageTypeTable19[16] =
{
    NULL, // 0
    &MessageTypeVar13, // 1
    &MessageTypeVar14, // 2
    &MessageTypeVar15, // 3
    NULL, // 4
    &MessageTypeVar17, // 5
    &MessageTypeVar18, // 6
    &MessageTypeVar19, // 7
    NULL, // 8
    &MessageTypeVar20, // 9
    NULL, // 10
    &MessageTypeVar22, // 11
    &MessageTypeVar23, // 12
    &MessageTypeVar24, // 13
    NULL, // 14
    NULL // 15
}; // MessageTypeTable19[]
const GED_MESSAGE_TYPE* MessageTypeTable20[16] =
{
    NULL, // 0
    NULL, // 1
    NULL, // 2
    NULL, // 3
    NULL, // 4
    NULL, // 5
    NULL, // 6
    NULL, // 7
    NULL, // 8
    NULL, // 9
    NULL, // 10
    NULL, // 11
    &MessageTypeVar48, // 12
    &MessageTypeVar49, // 13
    NULL, // 14
    NULL // 15
}; // MessageTypeTable20[]
const GED_MESSAGE_TYPE* MessageTypeTable21[32] =
{
    &MessageTypeVar12, // 0
    &MessageTypeVar13, // 1
    &MessageTypeVar14, // 2
    &MessageTypeVar15, // 3
    &MessageTypeVar16, // 4
    &MessageTypeVar17, // 5
    &MessageTypeVar18, // 6
    &MessageTypeVar19, // 7
    NULL, // 8
    &MessageTypeVar20, // 9
    &MessageTypeVar21, // 10
    &MessageTypeVar22, // 11
    &MessageTypeVar23, // 12
    &MessageTypeVar24, // 13
    NULL, // 14
    NULL, // 15
    &MessageTypeVar25, // 16
    &MessageTypeVar26, // 17
    &MessageTypeVar27, // 18
    &MessageTypeVar28, // 19
    &MessageTypeVar29, // 20
    &MessageTypeVar30, // 21
    NULL, // 22
    NULL, // 23
    &MessageTypeVar75, // 24
    &MessageTypeVar31, // 25
    &MessageTypeVar32, // 26
    NULL, // 27
    NULL, // 28
    NULL, // 29
    NULL, // 30
    NULL // 31
}; // MessageTypeTable21[]
const GED_MESSAGE_TYPE* MessageTypeTable22[32] =
{
    &MessageTypeVar12, // 0
    &MessageTypeVar13, // 1
    &MessageTypeVar14, // 2
    &MessageTypeVar15, // 3
    &MessageTypeVar16, // 4
    &MessageTypeVar17, // 5
    &MessageTypeVar18, // 6
    &MessageTypeVar19, // 7
    NULL, // 8
    &MessageTypeVar20, // 9
    &MessageTypeVar21, // 10
    &MessageTypeVar22, // 11
    &MessageTypeVar23, // 12
    &MessageTypeVar24, // 13
    NULL, // 14
    NULL, // 15
    &MessageTypeVar25, // 16
    &MessageTypeVar26, // 17
    &MessageTypeVar27, // 18
    &MessageTypeVar28, // 19
    &MessageTypeVar29, // 20
    &MessageTypeVar30, // 21
    NULL, // 22
    NULL, // 23
    NULL, // 24
    &MessageTypeVar31, // 25
    &MessageTypeVar32, // 26
    &MessageTypeVar54, // 27
    &MessageTypeVar75, // 28
    &MessageTypeVar56, // 29
    &MessageTypeVar76, // 30
    NULL // 31
}; // MessageTypeTable22[]
static GED_NO_SRC_DEP_SET NoSrcDepSetVar0 = (GED_NO_SRC_DEP_SET)0;
static GED_NO_SRC_DEP_SET NoSrcDepSetVar1 = (GED_NO_SRC_DEP_SET)1;
const GED_NO_SRC_DEP_SET* NoSrcDepSetTable0[2] =
{
    &NoSrcDepSetVar0, // 0
    &NoSrcDepSetVar1 // 1
}; // NoSrcDepSetTable0[]
static GED_OPCODE OpcodeVar0 = (GED_OPCODE)0;
static GED_OPCODE OpcodeVar1 = (GED_OPCODE)1;
static GED_OPCODE OpcodeVar2 = (GED_OPCODE)2;
static GED_OPCODE OpcodeVar3 = (GED_OPCODE)3;
static GED_OPCODE OpcodeVar4 = (GED_OPCODE)4;
static GED_OPCODE OpcodeVar5 = (GED_OPCODE)5;
static GED_OPCODE OpcodeVar6 = (GED_OPCODE)6;
static GED_OPCODE OpcodeVar7 = (GED_OPCODE)7;
static GED_OPCODE OpcodeVar8 = (GED_OPCODE)8;
static GED_OPCODE OpcodeVar9 = (GED_OPCODE)9;
static GED_OPCODE OpcodeVar10 = (GED_OPCODE)10;
static GED_OPCODE OpcodeVar11 = (GED_OPCODE)11;
static GED_OPCODE OpcodeVar12 = (GED_OPCODE)12;
static GED_OPCODE OpcodeVar13 = (GED_OPCODE)13;
static GED_OPCODE OpcodeVar14 = (GED_OPCODE)14;
static GED_OPCODE OpcodeVar15 = (GED_OPCODE)15;
static GED_OPCODE OpcodeVar16 = (GED_OPCODE)16;
static GED_OPCODE OpcodeVar17 = (GED_OPCODE)17;
static GED_OPCODE OpcodeVar18 = (GED_OPCODE)18;
static GED_OPCODE OpcodeVar19 = (GED_OPCODE)19;
static GED_OPCODE OpcodeVar20 = (GED_OPCODE)20;
static GED_OPCODE OpcodeVar21 = (GED_OPCODE)21;
static GED_OPCODE OpcodeVar22 = (GED_OPCODE)22;
static GED_OPCODE OpcodeVar23 = (GED_OPCODE)23;
static GED_OPCODE OpcodeVar24 = (GED_OPCODE)24;
static GED_OPCODE OpcodeVar25 = (GED_OPCODE)25;
static GED_OPCODE OpcodeVar26 = (GED_OPCODE)26;
static GED_OPCODE OpcodeVar27 = (GED_OPCODE)27;
static GED_OPCODE OpcodeVar28 = (GED_OPCODE)28;
static GED_OPCODE OpcodeVar29 = (GED_OPCODE)29;
static GED_OPCODE OpcodeVar30 = (GED_OPCODE)30;
static GED_OPCODE OpcodeVar31 = (GED_OPCODE)31;
static GED_OPCODE OpcodeVar32 = (GED_OPCODE)32;
static GED_OPCODE OpcodeVar33 = (GED_OPCODE)33;
static GED_OPCODE OpcodeVar34 = (GED_OPCODE)34;
static GED_OPCODE OpcodeVar35 = (GED_OPCODE)35;
static GED_OPCODE OpcodeVar36 = (GED_OPCODE)36;
static GED_OPCODE OpcodeVar37 = (GED_OPCODE)37;
static GED_OPCODE OpcodeVar38 = (GED_OPCODE)38;
static GED_OPCODE OpcodeVar39 = (GED_OPCODE)39;
static GED_OPCODE OpcodeVar40 = (GED_OPCODE)40;
static GED_OPCODE OpcodeVar41 = (GED_OPCODE)41;
static GED_OPCODE OpcodeVar42 = (GED_OPCODE)42;
static GED_OPCODE OpcodeVar43 = (GED_OPCODE)43;
static GED_OPCODE OpcodeVar44 = (GED_OPCODE)44;
static GED_OPCODE OpcodeVar45 = (GED_OPCODE)45;
static GED_OPCODE OpcodeVar46 = (GED_OPCODE)46;
static GED_OPCODE OpcodeVar47 = (GED_OPCODE)47;
static GED_OPCODE OpcodeVar48 = (GED_OPCODE)48;
static GED_OPCODE OpcodeVar49 = (GED_OPCODE)49;
static GED_OPCODE OpcodeVar50 = (GED_OPCODE)50;
static GED_OPCODE OpcodeVar51 = (GED_OPCODE)51;
static GED_OPCODE OpcodeVar52 = (GED_OPCODE)52;
static GED_OPCODE OpcodeVar53 = (GED_OPCODE)53;
static GED_OPCODE OpcodeVar54 = (GED_OPCODE)54;
static GED_OPCODE OpcodeVar55 = (GED_OPCODE)55;
static GED_OPCODE OpcodeVar56 = (GED_OPCODE)56;
static GED_OPCODE OpcodeVar57 = (GED_OPCODE)57;
static GED_OPCODE OpcodeVar58 = (GED_OPCODE)58;
static GED_OPCODE OpcodeVar59 = (GED_OPCODE)59;
static GED_OPCODE OpcodeVar60 = (GED_OPCODE)60;
static GED_OPCODE OpcodeVar61 = (GED_OPCODE)61;
static GED_OPCODE OpcodeVar62 = (GED_OPCODE)62;
static GED_OPCODE OpcodeVar63 = (GED_OPCODE)63;
static GED_OPCODE OpcodeVar64 = (GED_OPCODE)64;
static GED_OPCODE OpcodeVar65 = (GED_OPCODE)65;
static GED_OPCODE OpcodeVar66 = (GED_OPCODE)66;
static GED_OPCODE OpcodeVar67 = (GED_OPCODE)67;
static GED_OPCODE OpcodeVar68 = (GED_OPCODE)68;
static GED_OPCODE OpcodeVar69 = (GED_OPCODE)69;
static GED_OPCODE OpcodeVar70 = (GED_OPCODE)70;
static GED_OPCODE OpcodeVar71 = (GED_OPCODE)71;
static GED_OPCODE OpcodeVar72 = (GED_OPCODE)72;
static GED_OPCODE OpcodeVar73 = (GED_OPCODE)73;
static GED_OPCODE OpcodeVar74 = (GED_OPCODE)74;
static GED_OPCODE OpcodeVar75 = (GED_OPCODE)75;
static GED_OPCODE OpcodeVar76 = (GED_OPCODE)76;
static GED_OPCODE OpcodeVar77 = (GED_OPCODE)77;
static GED_OPCODE OpcodeVar78 = (GED_OPCODE)78;
static GED_OPCODE OpcodeVar79 = (GED_OPCODE)79;
static GED_OPCODE OpcodeVar80 = (GED_OPCODE)80;
static GED_OPCODE OpcodeVar81 = (GED_OPCODE)81;
const GED_OPCODE* OpcodeTable0[128] =
{
    &OpcodeVar0, // 0
    NULL, // 1
    NULL, // 2
    NULL, // 3
    NULL, // 4
    NULL, // 5
    NULL, // 6
    NULL, // 7
    NULL, // 8
    NULL, // 9
    NULL, // 10
    NULL, // 11
    NULL, // 12
    NULL, // 13
    NULL, // 14
    NULL, // 15
    NULL, // 16
    NULL, // 17
    NULL, // 18
    NULL, // 19
    NULL, // 20
    NULL, // 21
    NULL, // 22
    NULL, // 23
    NULL, // 24
    NULL, // 25
    NULL, // 26
    NULL, // 27
    NULL, // 28
    NULL, // 29
    NULL, // 30
    NULL, // 31
    NULL, // 32
    NULL, // 33
    NULL, // 34
    NULL, // 35
    NULL, // 36
    NULL, // 37
    NULL, // 38
    NULL, // 39
    NULL, // 40
    NULL, // 41
    NULL, // 42
    NULL, // 43
    NULL, // 44
    NULL, // 45
    NULL, // 46
    NULL, // 47
    NULL, // 48
    NULL, // 49
    NULL, // 50
    NULL, // 51
    NULL, // 52
    NULL, // 53
    NULL, // 54
    NULL, // 55
    NULL, // 56
    NULL, // 57
    NULL, // 58
    NULL, // 59
    NULL, // 60
    NULL, // 61
    NULL, // 62
    NULL, // 63
    NULL, // 64
    NULL, // 65
    NULL, // 66
    NULL, // 67
    NULL, // 68
    NULL, // 69
    NULL, // 70
    NULL, // 71
    NULL, // 72
    NULL, // 73
    NULL, // 74
    NULL, // 75
    NULL, // 76
    NULL, // 77
    NULL, // 78
    NULL, // 79
    NULL, // 80
    NULL, // 81
    NULL, // 82
    NULL, // 83
    NULL, // 84
    NULL, // 85
    NULL, // 86
    NULL, // 87
    NULL, // 88
    NULL, // 89
    NULL, // 90
    NULL, // 91
    NULL, // 92
    NULL, // 93
    NULL, // 94
    NULL, // 95
    NULL, // 96
    NULL, // 97
    NULL, // 98
    NULL, // 99
    NULL, // 100
    NULL, // 101
    NULL, // 102
    NULL, // 103
    NULL, // 104
    NULL, // 105
    NULL, // 106
    NULL, // 107
    NULL, // 108
    NULL, // 109
    NULL, // 110
    NULL, // 111
    NULL, // 112
    NULL, // 113
    NULL, // 114
    NULL, // 115
    NULL, // 116
    NULL, // 117
    NULL, // 118
    NULL, // 119
    NULL, // 120
    NULL, // 121
    NULL, // 122
    NULL, // 123
    NULL, // 124
    NULL, // 125
    NULL, // 126
    NULL // 127
}; // OpcodeTable0[]
const GED_OPCODE* OpcodeTable1[128] =
{
    &OpcodeVar1, // 0
    &OpcodeVar2, // 1
    &OpcodeVar3, // 2
    &OpcodeVar4, // 3
    &OpcodeVar5, // 4
    &OpcodeVar6, // 5
    &OpcodeVar7, // 6
    &OpcodeVar8, // 7
    &OpcodeVar9, // 8
    &OpcodeVar10, // 9
    &OpcodeVar11, // 10
    NULL, // 11
    &OpcodeVar12, // 12
    NULL, // 13
    NULL, // 14
    NULL, // 15
    &OpcodeVar13, // 16
    &OpcodeVar14, // 17
    &OpcodeVar15, // 18
    NULL, // 19
    NULL, // 20
    NULL, // 21
    NULL, // 22
    &OpcodeVar16, // 23
    &OpcodeVar17, // 24
    &OpcodeVar18, // 25
    &OpcodeVar19, // 26
    NULL, // 27
    NULL, // 28
    NULL, // 29
    NULL, // 30
    NULL, // 31
    &OpcodeVar20, // 32
    &OpcodeVar21, // 33
    &OpcodeVar22, // 34
    &OpcodeVar23, // 35
    &OpcodeVar24, // 36
    &OpcodeVar25, // 37
    NULL, // 38
    &OpcodeVar26, // 39
    &OpcodeVar27, // 40
    &OpcodeVar28, // 41
    &OpcodeVar29, // 42
    &OpcodeVar30, // 43
    &OpcodeVar31, // 44
    &OpcodeVar32, // 45
    &OpcodeVar33, // 46
    &OpcodeVar34, // 47
    &OpcodeVar35, // 48
    &OpcodeVar36, // 49
    &OpcodeVar37, // 50
    &OpcodeVar38, // 51
    &OpcodeVar39, // 52
    NULL, // 53
    NULL, // 54
    NULL, // 55
    &OpcodeVar40, // 56
    NULL, // 57
    NULL, // 58
    NULL, // 59
    NULL, // 60
    NULL, // 61
    NULL, // 62
    NULL, // 63
    &OpcodeVar41, // 64
    &OpcodeVar42, // 65
    &OpcodeVar43, // 66
    &OpcodeVar44, // 67
    &OpcodeVar45, // 68
    &OpcodeVar46, // 69
    &OpcodeVar47, // 70
    &OpcodeVar48, // 71
    &OpcodeVar49, // 72
    &OpcodeVar50, // 73
    &OpcodeVar51, // 74
    &OpcodeVar52, // 75
    &OpcodeVar53, // 76
    &OpcodeVar54, // 77
    &OpcodeVar55, // 78
    &OpcodeVar56, // 79
    &OpcodeVar57, // 80
    &OpcodeVar58, // 81
    NULL, // 82
    NULL, // 83
    &OpcodeVar59, // 84
    &OpcodeVar60, // 85
    &OpcodeVar61, // 86
    &OpcodeVar62, // 87
    NULL, // 88
    &OpcodeVar63, // 89
    &OpcodeVar64, // 90
    &OpcodeVar65, // 91
    &OpcodeVar66, // 92
    &OpcodeVar67, // 93
    NULL, // 94
    NULL, // 95
    NULL, // 96
    NULL, // 97
    NULL, // 98
    NULL, // 99
    NULL, // 100
    NULL, // 101
    NULL, // 102
    NULL, // 103
    NULL, // 104
    NULL, // 105
    NULL, // 106
    NULL, // 107
    NULL, // 108
    NULL, // 109
    NULL, // 110
    NULL, // 111
    NULL, // 112
    NULL, // 113
    NULL, // 114
    NULL, // 115
    NULL, // 116
    NULL, // 117
    NULL, // 118
    NULL, // 119
    NULL, // 120
    NULL, // 121
    NULL, // 122
    NULL, // 123
    NULL, // 124
    NULL, // 125
    &OpcodeVar68, // 126
    NULL // 127
}; // OpcodeTable1[]
const GED_OPCODE* OpcodeTable2[128] =
{
    &OpcodeVar1, // 0
    &OpcodeVar2, // 1
    &OpcodeVar3, // 2
    &OpcodeVar4, // 3
    &OpcodeVar5, // 4
    &OpcodeVar6, // 5
    &OpcodeVar7, // 6
    &OpcodeVar8, // 7
    &OpcodeVar9, // 8
    &OpcodeVar10, // 9
    &OpcodeVar11, // 10
    NULL, // 11
    &OpcodeVar12, // 12
    NULL, // 13
    &OpcodeVar69, // 14
    &OpcodeVar70, // 15
    &OpcodeVar13, // 16
    &OpcodeVar14, // 17
    &OpcodeVar15, // 18
    NULL, // 19
    NULL, // 20
    NULL, // 21
    NULL, // 22
    &OpcodeVar16, // 23
    &OpcodeVar17, // 24
    &OpcodeVar18, // 25
    &OpcodeVar19, // 26
    NULL, // 27
    NULL, // 28
    NULL, // 29
    NULL, // 30
    NULL, // 31
    &OpcodeVar20, // 32
    &OpcodeVar21, // 33
    &OpcodeVar22, // 34
    &OpcodeVar23, // 35
    &OpcodeVar24, // 36
    &OpcodeVar25, // 37
    NULL, // 38
    &OpcodeVar26, // 39
    &OpcodeVar27, // 40
    &OpcodeVar28, // 41
    &OpcodeVar29, // 42
    &OpcodeVar30, // 43
    &OpcodeVar31, // 44
    &OpcodeVar32, // 45
    &OpcodeVar33, // 46
    &OpcodeVar34, // 47
    &OpcodeVar35, // 48
    &OpcodeVar36, // 49
    &OpcodeVar37, // 50
    &OpcodeVar38, // 51
    &OpcodeVar39, // 52
    NULL, // 53
    NULL, // 54
    NULL, // 55
    &OpcodeVar40, // 56
    NULL, // 57
    NULL, // 58
    NULL, // 59
    NULL, // 60
    NULL, // 61
    NULL, // 62
    NULL, // 63
    &OpcodeVar41, // 64
    &OpcodeVar42, // 65
    &OpcodeVar43, // 66
    &OpcodeVar44, // 67
    &OpcodeVar45, // 68
    &OpcodeVar46, // 69
    &OpcodeVar47, // 70
    &OpcodeVar48, // 71
    &OpcodeVar49, // 72
    &OpcodeVar50, // 73
    &OpcodeVar51, // 74
    &OpcodeVar52, // 75
    &OpcodeVar53, // 76
    &OpcodeVar54, // 77
    &OpcodeVar55, // 78
    &OpcodeVar56, // 79
    &OpcodeVar57, // 80
    &OpcodeVar58, // 81
    NULL, // 82
    NULL, // 83
    NULL, // 84
    NULL, // 85
    NULL, // 86
    NULL, // 87
    &OpcodeVar71, // 88
    NULL, // 89
    NULL, // 90
    &OpcodeVar65, // 91
    NULL, // 92
    &OpcodeVar67, // 93
    NULL, // 94
    NULL, // 95
    NULL, // 96
    NULL, // 97
    NULL, // 98
    NULL, // 99
    NULL, // 100
    NULL, // 101
    NULL, // 102
    NULL, // 103
    NULL, // 104
    NULL, // 105
    NULL, // 106
    NULL, // 107
    NULL, // 108
    NULL, // 109
    NULL, // 110
    NULL, // 111
    NULL, // 112
    NULL, // 113
    NULL, // 114
    NULL, // 115
    NULL, // 116
    NULL, // 117
    NULL, // 118
    NULL, // 119
    NULL, // 120
    NULL, // 121
    NULL, // 122
    NULL, // 123
    NULL, // 124
    NULL, // 125
    &OpcodeVar68, // 126
    NULL // 127
}; // OpcodeTable2[]
const GED_OPCODE* OpcodeTable3[128] =
{
    &OpcodeVar1, // 0
    &OpcodeVar72, // 1
    NULL, // 2
    NULL, // 3
    NULL, // 4
    NULL, // 5
    NULL, // 6
    NULL, // 7
    NULL, // 8
    NULL, // 9
    NULL, // 10
    NULL, // 11
    NULL, // 12
    NULL, // 13
    NULL, // 14
    NULL, // 15
    NULL, // 16
    NULL, // 17
    NULL, // 18
    NULL, // 19
    NULL, // 20
    NULL, // 21
    NULL, // 22
    NULL, // 23
    NULL, // 24
    NULL, // 25
    NULL, // 26
    NULL, // 27
    NULL, // 28
    NULL, // 29
    NULL, // 30
    NULL, // 31
    &OpcodeVar20, // 32
    &OpcodeVar21, // 33
    &OpcodeVar22, // 34
    &OpcodeVar23, // 35
    &OpcodeVar24, // 36
    &OpcodeVar25, // 37
    NULL, // 38
    &OpcodeVar26, // 39
    &OpcodeVar27, // 40
    &OpcodeVar28, // 41
    &OpcodeVar29, // 42
    &OpcodeVar30, // 43
    &OpcodeVar31, // 44
    &OpcodeVar32, // 45
    &OpcodeVar33, // 46
    &OpcodeVar34, // 47
    NULL, // 48
    &OpcodeVar36, // 49
    &OpcodeVar37, // 50
    NULL, // 51
    NULL, // 52
    NULL, // 53
    NULL, // 54
    NULL, // 55
    &OpcodeVar40, // 56
    NULL, // 57
    NULL, // 58
    NULL, // 59
    NULL, // 60
    NULL, // 61
    NULL, // 62
    NULL, // 63
    &OpcodeVar41, // 64
    &OpcodeVar42, // 65
    &OpcodeVar43, // 66
    &OpcodeVar44, // 67
    &OpcodeVar45, // 68
    &OpcodeVar46, // 69
    &OpcodeVar47, // 70
    &OpcodeVar48, // 71
    &OpcodeVar49, // 72
    &OpcodeVar50, // 73
    &OpcodeVar51, // 74
    &OpcodeVar52, // 75
    &OpcodeVar53, // 76
    &OpcodeVar54, // 77
    &OpcodeVar55, // 78
    &OpcodeVar56, // 79
    &OpcodeVar57, // 80
    &OpcodeVar58, // 81
    NULL, // 82
    NULL, // 83
    NULL, // 84
    NULL, // 85
    NULL, // 86
    NULL, // 87
    &OpcodeVar71, // 88
    NULL, // 89
    NULL, // 90
    &OpcodeVar65, // 91
    NULL, // 92
    NULL, // 93
    NULL, // 94
    NULL, // 95
    &OpcodeVar68, // 96
    &OpcodeVar2, // 97
    &OpcodeVar3, // 98
    &OpcodeVar4, // 99
    &OpcodeVar5, // 100
    &OpcodeVar6, // 101
    &OpcodeVar7, // 102
    &OpcodeVar8, // 103
    &OpcodeVar9, // 104
    &OpcodeVar10, // 105
    NULL, // 106
    NULL, // 107
    &OpcodeVar12, // 108
    NULL, // 109
    &OpcodeVar69, // 110
    &OpcodeVar70, // 111
    &OpcodeVar13, // 112
    &OpcodeVar14, // 113
    &OpcodeVar15, // 114
    NULL, // 115
    NULL, // 116
    NULL, // 117
    NULL, // 118
    &OpcodeVar16, // 119
    &OpcodeVar17, // 120
    &OpcodeVar18, // 121
    &OpcodeVar19, // 122
    NULL, // 123
    NULL, // 124
    NULL, // 125
    NULL, // 126
    NULL // 127
}; // OpcodeTable3[]
const GED_OPCODE* OpcodeTable4[128] =
{
    &OpcodeVar1, // 0
    &OpcodeVar72, // 1
    NULL, // 2
    NULL, // 3
    NULL, // 4
    NULL, // 5
    NULL, // 6
    NULL, // 7
    NULL, // 8
    NULL, // 9
    NULL, // 10
    NULL, // 11
    NULL, // 12
    NULL, // 13
    NULL, // 14
    NULL, // 15
    NULL, // 16
    NULL, // 17
    NULL, // 18
    NULL, // 19
    NULL, // 20
    NULL, // 21
    NULL, // 22
    NULL, // 23
    NULL, // 24
    NULL, // 25
    NULL, // 26
    NULL, // 27
    NULL, // 28
    NULL, // 29
    NULL, // 30
    NULL, // 31
    &OpcodeVar20, // 32
    &OpcodeVar21, // 33
    &OpcodeVar22, // 34
    &OpcodeVar23, // 35
    &OpcodeVar24, // 36
    &OpcodeVar25, // 37
    NULL, // 38
    &OpcodeVar26, // 39
    &OpcodeVar27, // 40
    &OpcodeVar28, // 41
    &OpcodeVar29, // 42
    &OpcodeVar30, // 43
    &OpcodeVar31, // 44
    &OpcodeVar32, // 45
    &OpcodeVar33, // 46
    &OpcodeVar34, // 47
    NULL, // 48
    &OpcodeVar36, // 49
    &OpcodeVar37, // 50
    NULL, // 51
    NULL, // 52
    NULL, // 53
    NULL, // 54
    NULL, // 55
    &OpcodeVar40, // 56
    NULL, // 57
    NULL, // 58
    NULL, // 59
    NULL, // 60
    NULL, // 61
    NULL, // 62
    NULL, // 63
    &OpcodeVar41, // 64
    &OpcodeVar42, // 65
    &OpcodeVar43, // 66
    &OpcodeVar44, // 67
    &OpcodeVar45, // 68
    &OpcodeVar46, // 69
    &OpcodeVar47, // 70
    &OpcodeVar48, // 71
    &OpcodeVar49, // 72
    &OpcodeVar50, // 73
    &OpcodeVar51, // 74
    &OpcodeVar52, // 75
    &OpcodeVar53, // 76
    &OpcodeVar54, // 77
    &OpcodeVar55, // 78
    &OpcodeVar56, // 79
    &OpcodeVar57, // 80
    &OpcodeVar58, // 81
    &OpcodeVar73, // 82
    NULL, // 83
    NULL, // 84
    NULL, // 85
    NULL, // 86
    NULL, // 87
    &OpcodeVar71, // 88
    &OpcodeVar74, // 89
    &OpcodeVar75, // 90
    &OpcodeVar65, // 91
    NULL, // 92
    &OpcodeVar67, // 93
    NULL, // 94
    NULL, // 95
    &OpcodeVar68, // 96
    &OpcodeVar2, // 97
    &OpcodeVar3, // 98
    &OpcodeVar4, // 99
    &OpcodeVar5, // 100
    &OpcodeVar6, // 101
    &OpcodeVar7, // 102
    &OpcodeVar8, // 103
    &OpcodeVar9, // 104
    &OpcodeVar10, // 105
    NULL, // 106
    &OpcodeVar76, // 107
    &OpcodeVar12, // 108
    NULL, // 109
    &OpcodeVar69, // 110
    &OpcodeVar70, // 111
    &OpcodeVar13, // 112
    &OpcodeVar14, // 113
    &OpcodeVar15, // 114
    NULL, // 115
    NULL, // 116
    NULL, // 117
    NULL, // 118
    &OpcodeVar16, // 119
    &OpcodeVar17, // 120
    &OpcodeVar18, // 121
    &OpcodeVar19, // 122
    NULL, // 123
    NULL, // 124
    NULL, // 125
    NULL, // 126
    NULL // 127
}; // OpcodeTable4[]
const GED_OPCODE* OpcodeTable5[128] =
{
    &OpcodeVar1, // 0
    &OpcodeVar72, // 1
    NULL, // 2
    NULL, // 3
    NULL, // 4
    NULL, // 5
    NULL, // 6
    NULL, // 7
    NULL, // 8
    NULL, // 9
    NULL, // 10
    NULL, // 11
    NULL, // 12
    NULL, // 13
    NULL, // 14
    NULL, // 15
    NULL, // 16
    NULL, // 17
    NULL, // 18
    NULL, // 19
    NULL, // 20
    NULL, // 21
    NULL, // 22
    NULL, // 23
    NULL, // 24
    NULL, // 25
    NULL, // 26
    NULL, // 27
    NULL, // 28
    NULL, // 29
    NULL, // 30
    NULL, // 31
    &OpcodeVar20, // 32
    &OpcodeVar21, // 33
    &OpcodeVar22, // 34
    &OpcodeVar23, // 35
    &OpcodeVar24, // 36
    &OpcodeVar25, // 37
    NULL, // 38
    &OpcodeVar26, // 39
    &OpcodeVar27, // 40
    &OpcodeVar28, // 41
    &OpcodeVar29, // 42
    &OpcodeVar30, // 43
    &OpcodeVar31, // 44
    &OpcodeVar32, // 45
    &OpcodeVar33, // 46
    &OpcodeVar34, // 47
    NULL, // 48
    &OpcodeVar36, // 49
    &OpcodeVar37, // 50
    NULL, // 51
    NULL, // 52
    NULL, // 53
    NULL, // 54
    NULL, // 55
    &OpcodeVar40, // 56
    NULL, // 57
    NULL, // 58
    NULL, // 59
    NULL, // 60
    NULL, // 61
    NULL, // 62
    NULL, // 63
    &OpcodeVar41, // 64
    &OpcodeVar42, // 65
    &OpcodeVar43, // 66
    &OpcodeVar44, // 67
    &OpcodeVar45, // 68
    &OpcodeVar46, // 69
    &OpcodeVar47, // 70
    &OpcodeVar48, // 71
    &OpcodeVar49, // 72
    &OpcodeVar50, // 73
    &OpcodeVar51, // 74
    &OpcodeVar52, // 75
    &OpcodeVar53, // 76
    &OpcodeVar54, // 77
    &OpcodeVar55, // 78
    &OpcodeVar56, // 79
    NULL, // 80
    NULL, // 81
    &OpcodeVar73, // 82
    &OpcodeVar77, // 83
    NULL, // 84
    NULL, // 85
    NULL, // 86
    NULL, // 87
    &OpcodeVar71, // 88
    &OpcodeVar74, // 89
    NULL, // 90
    &OpcodeVar65, // 91
    NULL, // 92
    &OpcodeVar67, // 93
    NULL, // 94
    NULL, // 95
    &OpcodeVar68, // 96
    &OpcodeVar2, // 97
    &OpcodeVar3, // 98
    &OpcodeVar4, // 99
    &OpcodeVar5, // 100
    &OpcodeVar6, // 101
    &OpcodeVar7, // 102
    &OpcodeVar8, // 103
    &OpcodeVar9, // 104
    &OpcodeVar10, // 105
    NULL, // 106
    &OpcodeVar76, // 107
    &OpcodeVar12, // 108
    NULL, // 109
    &OpcodeVar69, // 110
    &OpcodeVar70, // 111
    &OpcodeVar13, // 112
    &OpcodeVar14, // 113
    &OpcodeVar15, // 114
    NULL, // 115
    NULL, // 116
    NULL, // 117
    NULL, // 118
    &OpcodeVar16, // 119
    &OpcodeVar17, // 120
    &OpcodeVar18, // 121
    &OpcodeVar19, // 122
    NULL, // 123
    NULL, // 124
    NULL, // 125
    NULL, // 126
    NULL // 127
}; // OpcodeTable5[]
const GED_OPCODE* OpcodeTable6[128] =
{
    &OpcodeVar1, // 0
    &OpcodeVar72, // 1
    NULL, // 2
    NULL, // 3
    NULL, // 4
    NULL, // 5
    NULL, // 6
    NULL, // 7
    NULL, // 8
    NULL, // 9
    NULL, // 10
    NULL, // 11
    NULL, // 12
    NULL, // 13
    NULL, // 14
    NULL, // 15
    NULL, // 16
    NULL, // 17
    NULL, // 18
    NULL, // 19
    NULL, // 20
    NULL, // 21
    NULL, // 22
    NULL, // 23
    NULL, // 24
    NULL, // 25
    NULL, // 26
    NULL, // 27
    NULL, // 28
    NULL, // 29
    NULL, // 30
    NULL, // 31
    &OpcodeVar20, // 32
    &OpcodeVar21, // 33
    &OpcodeVar22, // 34
    &OpcodeVar23, // 35
    &OpcodeVar24, // 36
    &OpcodeVar25, // 37
    NULL, // 38
    &OpcodeVar26, // 39
    &OpcodeVar27, // 40
    &OpcodeVar28, // 41
    &OpcodeVar29, // 42
    &OpcodeVar30, // 43
    &OpcodeVar31, // 44
    &OpcodeVar32, // 45
    &OpcodeVar33, // 46
    &OpcodeVar34, // 47
    NULL, // 48
    &OpcodeVar36, // 49
    &OpcodeVar37, // 50
    NULL, // 51
    NULL, // 52
    NULL, // 53
    NULL, // 54
    NULL, // 55
    &OpcodeVar40, // 56
    NULL, // 57
    NULL, // 58
    NULL, // 59
    NULL, // 60
    NULL, // 61
    NULL, // 62
    NULL, // 63
    &OpcodeVar41, // 64
    &OpcodeVar42, // 65
    &OpcodeVar43, // 66
    &OpcodeVar44, // 67
    &OpcodeVar45, // 68
    &OpcodeVar46, // 69
    &OpcodeVar47, // 70
    &OpcodeVar48, // 71
    &OpcodeVar49, // 72
    &OpcodeVar50, // 73
    &OpcodeVar51, // 74
    &OpcodeVar52, // 75
    &OpcodeVar53, // 76
    &OpcodeVar54, // 77
    &OpcodeVar55, // 78
    &OpcodeVar56, // 79
    NULL, // 80
    NULL, // 81
    &OpcodeVar73, // 82
    &OpcodeVar77, // 83
    &OpcodeVar78, // 84
    NULL, // 85
    NULL, // 86
    NULL, // 87
    &OpcodeVar71, // 88
    &OpcodeVar74, // 89
    NULL, // 90
    &OpcodeVar65, // 91
    NULL, // 92
    &OpcodeVar67, // 93
    NULL, // 94
    NULL, // 95
    &OpcodeVar68, // 96
    &OpcodeVar2, // 97
    &OpcodeVar3, // 98
    &OpcodeVar4, // 99
    &OpcodeVar5, // 100
    &OpcodeVar6, // 101
    &OpcodeVar7, // 102
    &OpcodeVar8, // 103
    &OpcodeVar9, // 104
    &OpcodeVar10, // 105
    NULL, // 106
    &OpcodeVar76, // 107
    &OpcodeVar12, // 108
    NULL, // 109
    &OpcodeVar69, // 110
    &OpcodeVar70, // 111
    &OpcodeVar13, // 112
    &OpcodeVar14, // 113
    &OpcodeVar15, // 114
    NULL, // 115
    NULL, // 116
    NULL, // 117
    NULL, // 118
    &OpcodeVar16, // 119
    &OpcodeVar17, // 120
    &OpcodeVar18, // 121
    &OpcodeVar19, // 122
    NULL, // 123
    NULL, // 124
    NULL, // 125
    NULL, // 126
    NULL // 127
}; // OpcodeTable6[]
const GED_OPCODE* OpcodeTable7[128] =
{
    &OpcodeVar1, // 0
    &OpcodeVar72, // 1
    NULL, // 2
    NULL, // 3
    NULL, // 4
    NULL, // 5
    NULL, // 6
    NULL, // 7
    NULL, // 8
    NULL, // 9
    NULL, // 10
    NULL, // 11
    NULL, // 12
    NULL, // 13
    NULL, // 14
    NULL, // 15
    NULL, // 16
    NULL, // 17
    NULL, // 18
    NULL, // 19
    NULL, // 20
    NULL, // 21
    NULL, // 22
    NULL, // 23
    NULL, // 24
    NULL, // 25
    NULL, // 26
    NULL, // 27
    NULL, // 28
    NULL, // 29
    NULL, // 30
    NULL, // 31
    &OpcodeVar20, // 32
    &OpcodeVar21, // 33
    &OpcodeVar22, // 34
    &OpcodeVar23, // 35
    &OpcodeVar24, // 36
    &OpcodeVar25, // 37
    NULL, // 38
    &OpcodeVar26, // 39
    &OpcodeVar27, // 40
    &OpcodeVar28, // 41
    &OpcodeVar29, // 42
    &OpcodeVar30, // 43
    &OpcodeVar31, // 44
    &OpcodeVar32, // 45
    &OpcodeVar33, // 46
    &OpcodeVar34, // 47
    NULL, // 48
    &OpcodeVar36, // 49
    &OpcodeVar37, // 50
    NULL, // 51
    NULL, // 52
    NULL, // 53
    NULL, // 54
    NULL, // 55
    &OpcodeVar40, // 56
    NULL, // 57
    NULL, // 58
    NULL, // 59
    NULL, // 60
    NULL, // 61
    NULL, // 62
    NULL, // 63
    &OpcodeVar41, // 64
    &OpcodeVar42, // 65
    &OpcodeVar43, // 66
    &OpcodeVar44, // 67
    &OpcodeVar45, // 68
    &OpcodeVar46, // 69
    &OpcodeVar47, // 70
    &OpcodeVar48, // 71
    &OpcodeVar49, // 72
    &OpcodeVar50, // 73
    &OpcodeVar51, // 74
    &OpcodeVar52, // 75
    &OpcodeVar53, // 76
    &OpcodeVar54, // 77
    &OpcodeVar55, // 78
    &OpcodeVar56, // 79
    &OpcodeVar57, // 80
    &OpcodeVar58, // 81
    &OpcodeVar73, // 82
    NULL, // 83
    NULL, // 84
    NULL, // 85
    NULL, // 86
    NULL, // 87
    &OpcodeVar71, // 88
    NULL, // 89
    NULL, // 90
    &OpcodeVar65, // 91
    NULL, // 92
    &OpcodeVar67, // 93
    NULL, // 94
    NULL, // 95
    &OpcodeVar68, // 96
    &OpcodeVar2, // 97
    &OpcodeVar3, // 98
    &OpcodeVar4, // 99
    &OpcodeVar5, // 100
    &OpcodeVar6, // 101
    &OpcodeVar7, // 102
    &OpcodeVar8, // 103
    &OpcodeVar9, // 104
    &OpcodeVar10, // 105
    NULL, // 106
    &OpcodeVar76, // 107
    &OpcodeVar12, // 108
    NULL, // 109
    &OpcodeVar69, // 110
    &OpcodeVar70, // 111
    &OpcodeVar13, // 112
    &OpcodeVar14, // 113
    &OpcodeVar15, // 114
    NULL, // 115
    NULL, // 116
    NULL, // 117
    NULL, // 118
    &OpcodeVar16, // 119
    &OpcodeVar17, // 120
    &OpcodeVar18, // 121
    &OpcodeVar19, // 122
    NULL, // 123
    NULL, // 124
    NULL, // 125
    NULL, // 126
    NULL // 127
}; // OpcodeTable7[]
const GED_OPCODE* OpcodeTable8[128] =
{
    &OpcodeVar1, // 0
    &OpcodeVar2, // 1
    &OpcodeVar3, // 2
    &OpcodeVar4, // 3
    &OpcodeVar5, // 4
    &OpcodeVar6, // 5
    &OpcodeVar7, // 6
    &OpcodeVar8, // 7
    &OpcodeVar9, // 8
    &OpcodeVar10, // 9
    NULL, // 10
    NULL, // 11
    &OpcodeVar12, // 12
    NULL, // 13
    NULL, // 14
    NULL, // 15
    &OpcodeVar13, // 16
    &OpcodeVar14, // 17
    &OpcodeVar15, // 18
    &OpcodeVar79, // 19
    &OpcodeVar80, // 20
    NULL, // 21
    NULL, // 22
    &OpcodeVar16, // 23
    &OpcodeVar17, // 24
    &OpcodeVar18, // 25
    &OpcodeVar19, // 26
    NULL, // 27
    NULL, // 28
    NULL, // 29
    NULL, // 30
    NULL, // 31
    &OpcodeVar20, // 32
    &OpcodeVar21, // 33
    &OpcodeVar22, // 34
    &OpcodeVar23, // 35
    &OpcodeVar24, // 36
    &OpcodeVar25, // 37
    NULL, // 38
    &OpcodeVar26, // 39
    &OpcodeVar27, // 40
    &OpcodeVar28, // 41
    &OpcodeVar29, // 42
    NULL, // 43
    &OpcodeVar31, // 44
    &OpcodeVar32, // 45
    NULL, // 46
    NULL, // 47
    &OpcodeVar35, // 48
    &OpcodeVar36, // 49
    &OpcodeVar37, // 50
    NULL, // 51
    NULL, // 52
    NULL, // 53
    NULL, // 54
    NULL, // 55
    &OpcodeVar40, // 56
    NULL, // 57
    NULL, // 58
    NULL, // 59
    NULL, // 60
    NULL, // 61
    NULL, // 62
    NULL, // 63
    &OpcodeVar41, // 64
    &OpcodeVar42, // 65
    &OpcodeVar43, // 66
    &OpcodeVar44, // 67
    &OpcodeVar45, // 68
    &OpcodeVar46, // 69
    &OpcodeVar47, // 70
    &OpcodeVar48, // 71
    &OpcodeVar49, // 72
    &OpcodeVar50, // 73
    &OpcodeVar51, // 74
    &OpcodeVar52, // 75
    &OpcodeVar53, // 76
    &OpcodeVar54, // 77
    &OpcodeVar55, // 78
    &OpcodeVar56, // 79
    &OpcodeVar57, // 80
    &OpcodeVar58, // 81
    NULL, // 82
    NULL, // 83
    &OpcodeVar59, // 84
    &OpcodeVar60, // 85
    &OpcodeVar61, // 86
    &OpcodeVar62, // 87
    NULL, // 88
    &OpcodeVar63, // 89
    &OpcodeVar64, // 90
    &OpcodeVar65, // 91
    &OpcodeVar66, // 92
    NULL, // 93
    NULL, // 94
    NULL, // 95
    NULL, // 96
    NULL, // 97
    NULL, // 98
    NULL, // 99
    NULL, // 100
    NULL, // 101
    NULL, // 102
    NULL, // 103
    NULL, // 104
    NULL, // 105
    NULL, // 106
    NULL, // 107
    NULL, // 108
    NULL, // 109
    NULL, // 110
    NULL, // 111
    NULL, // 112
    NULL, // 113
    NULL, // 114
    NULL, // 115
    NULL, // 116
    NULL, // 117
    NULL, // 118
    NULL, // 119
    NULL, // 120
    NULL, // 121
    NULL, // 122
    NULL, // 123
    NULL, // 124
    NULL, // 125
    &OpcodeVar68, // 126
    NULL // 127
}; // OpcodeTable8[]
const GED_OPCODE* OpcodeTable9[128] =
{
    &OpcodeVar1, // 0
    &OpcodeVar2, // 1
    &OpcodeVar3, // 2
    &OpcodeVar4, // 3
    &OpcodeVar5, // 4
    &OpcodeVar6, // 5
    &OpcodeVar7, // 6
    &OpcodeVar8, // 7
    &OpcodeVar9, // 8
    &OpcodeVar10, // 9
    &OpcodeVar81, // 10
    NULL, // 11
    &OpcodeVar12, // 12
    NULL, // 13
    NULL, // 14
    NULL, // 15
    &OpcodeVar13, // 16
    &OpcodeVar14, // 17
    &OpcodeVar15, // 18
    &OpcodeVar79, // 19
    &OpcodeVar80, // 20
    NULL, // 21
    NULL, // 22
    &OpcodeVar16, // 23
    &OpcodeVar17, // 24
    &OpcodeVar18, // 25
    &OpcodeVar19, // 26
    NULL, // 27
    NULL, // 28
    NULL, // 29
    NULL, // 30
    NULL, // 31
    &OpcodeVar20, // 32
    &OpcodeVar21, // 33
    &OpcodeVar22, // 34
    &OpcodeVar23, // 35
    &OpcodeVar24, // 36
    &OpcodeVar25, // 37
    NULL, // 38
    &OpcodeVar26, // 39
    &OpcodeVar27, // 40
    &OpcodeVar28, // 41
    &OpcodeVar29, // 42
    &OpcodeVar30, // 43
    &OpcodeVar31, // 44
    &OpcodeVar32, // 45
    NULL, // 46
    NULL, // 47
    &OpcodeVar35, // 48
    &OpcodeVar36, // 49
    &OpcodeVar37, // 50
    NULL, // 51
    NULL, // 52
    NULL, // 53
    NULL, // 54
    NULL, // 55
    &OpcodeVar40, // 56
    NULL, // 57
    NULL, // 58
    NULL, // 59
    NULL, // 60
    NULL, // 61
    NULL, // 62
    NULL, // 63
    &OpcodeVar41, // 64
    &OpcodeVar42, // 65
    &OpcodeVar43, // 66
    &OpcodeVar44, // 67
    &OpcodeVar45, // 68
    &OpcodeVar46, // 69
    &OpcodeVar47, // 70
    &OpcodeVar48, // 71
    &OpcodeVar49, // 72
    &OpcodeVar50, // 73
    &OpcodeVar51, // 74
    &OpcodeVar52, // 75
    &OpcodeVar53, // 76
    &OpcodeVar54, // 77
    &OpcodeVar55, // 78
    &OpcodeVar56, // 79
    &OpcodeVar57, // 80
    &OpcodeVar58, // 81
    NULL, // 82
    NULL, // 83
    &OpcodeVar59, // 84
    &OpcodeVar60, // 85
    &OpcodeVar61, // 86
    &OpcodeVar62, // 87
    NULL, // 88
    &OpcodeVar63, // 89
    &OpcodeVar64, // 90
    &OpcodeVar65, // 91
    &OpcodeVar66, // 92
    NULL, // 93
    NULL, // 94
    NULL, // 95
    NULL, // 96
    NULL, // 97
    NULL, // 98
    NULL, // 99
    NULL, // 100
    NULL, // 101
    NULL, // 102
    NULL, // 103
    NULL, // 104
    NULL, // 105
    NULL, // 106
    NULL, // 107
    NULL, // 108
    NULL, // 109
    NULL, // 110
    NULL, // 111
    NULL, // 112
    NULL, // 113
    NULL, // 114
    NULL, // 115
    NULL, // 116
    NULL, // 117
    NULL, // 118
    NULL, // 119
    NULL, // 120
    NULL, // 121
    NULL, // 122
    NULL, // 123
    NULL, // 124
    NULL, // 125
    &OpcodeVar68, // 126
    NULL // 127
}; // OpcodeTable9[]
const GED_OPCODE* OpcodeTable10[128] =
{
    &OpcodeVar1, // 0
    &OpcodeVar2, // 1
    &OpcodeVar3, // 2
    &OpcodeVar4, // 3
    &OpcodeVar5, // 4
    &OpcodeVar6, // 5
    &OpcodeVar7, // 6
    &OpcodeVar8, // 7
    &OpcodeVar9, // 8
    &OpcodeVar10, // 9
    &OpcodeVar11, // 10
    NULL, // 11
    &OpcodeVar12, // 12
    NULL, // 13
    NULL, // 14
    NULL, // 15
    &OpcodeVar13, // 16
    &OpcodeVar14, // 17
    &OpcodeVar15, // 18
    NULL, // 19
    NULL, // 20
    NULL, // 21
    NULL, // 22
    &OpcodeVar16, // 23
    &OpcodeVar17, // 24
    &OpcodeVar18, // 25
    &OpcodeVar19, // 26
    NULL, // 27
    NULL, // 28
    NULL, // 29
    NULL, // 30
    NULL, // 31
    &OpcodeVar20, // 32
    &OpcodeVar21, // 33
    &OpcodeVar22, // 34
    &OpcodeVar23, // 35
    &OpcodeVar24, // 36
    &OpcodeVar25, // 37
    NULL, // 38
    &OpcodeVar26, // 39
    &OpcodeVar27, // 40
    &OpcodeVar28, // 41
    &OpcodeVar29, // 42
    &OpcodeVar30, // 43
    &OpcodeVar31, // 44
    &OpcodeVar32, // 45
    &OpcodeVar33, // 46
    &OpcodeVar34, // 47
    &OpcodeVar35, // 48
    &OpcodeVar36, // 49
    &OpcodeVar37, // 50
    NULL, // 51
    NULL, // 52
    NULL, // 53
    NULL, // 54
    NULL, // 55
    &OpcodeVar40, // 56
    NULL, // 57
    NULL, // 58
    NULL, // 59
    NULL, // 60
    NULL, // 61
    NULL, // 62
    NULL, // 63
    &OpcodeVar41, // 64
    &OpcodeVar42, // 65
    &OpcodeVar43, // 66
    &OpcodeVar44, // 67
    &OpcodeVar45, // 68
    &OpcodeVar46, // 69
    &OpcodeVar47, // 70
    &OpcodeVar48, // 71
    &OpcodeVar49, // 72
    &OpcodeVar50, // 73
    &OpcodeVar51, // 74
    &OpcodeVar52, // 75
    &OpcodeVar53, // 76
    &OpcodeVar54, // 77
    &OpcodeVar55, // 78
    &OpcodeVar56, // 79
    &OpcodeVar57, // 80
    &OpcodeVar58, // 81
    NULL, // 82
    NULL, // 83
    &OpcodeVar59, // 84
    &OpcodeVar60, // 85
    &OpcodeVar61, // 86
    &OpcodeVar62, // 87
    NULL, // 88
    &OpcodeVar63, // 89
    &OpcodeVar64, // 90
    &OpcodeVar65, // 91
    &OpcodeVar66, // 92
    &OpcodeVar67, // 93
    NULL, // 94
    NULL, // 95
    NULL, // 96
    NULL, // 97
    NULL, // 98
    NULL, // 99
    NULL, // 100
    NULL, // 101
    NULL, // 102
    NULL, // 103
    NULL, // 104
    NULL, // 105
    NULL, // 106
    NULL, // 107
    NULL, // 108
    NULL, // 109
    NULL, // 110
    NULL, // 111
    NULL, // 112
    NULL, // 113
    NULL, // 114
    NULL, // 115
    NULL, // 116
    NULL, // 117
    NULL, // 118
    NULL, // 119
    NULL, // 120
    NULL, // 121
    NULL, // 122
    NULL, // 123
    NULL, // 124
    NULL, // 125
    &OpcodeVar68, // 126
    NULL // 127
}; // OpcodeTable10[]
static GED_PRECISION PrecisionVar0 = (GED_PRECISION)0;
static GED_PRECISION PrecisionVar1 = (GED_PRECISION)1;
static GED_PRECISION PrecisionVar2 = (GED_PRECISION)2;
static GED_PRECISION PrecisionVar3 = (GED_PRECISION)3;
static GED_PRECISION PrecisionVar4 = (GED_PRECISION)4;
static GED_PRECISION PrecisionVar5 = (GED_PRECISION)5;
static GED_PRECISION PrecisionVar6 = (GED_PRECISION)6;
static GED_PRECISION PrecisionVar7 = (GED_PRECISION)7;
static GED_PRECISION PrecisionVar8 = (GED_PRECISION)8;
static GED_PRECISION PrecisionVar9 = (GED_PRECISION)9;
static GED_PRECISION PrecisionVar10 = (GED_PRECISION)10;
static GED_PRECISION PrecisionVar11 = (GED_PRECISION)11;
static GED_PRECISION PrecisionVar12 = (GED_PRECISION)12;
const GED_PRECISION* PrecisionTable0[32] =
{
    &PrecisionVar0, // 0
    &PrecisionVar1, // 1
    &PrecisionVar2, // 2
    &PrecisionVar3, // 3
    NULL, // 4
    NULL, // 5
    NULL, // 6
    NULL, // 7
    NULL, // 8
    NULL, // 9
    NULL, // 10
    NULL, // 11
    NULL, // 12
    NULL, // 13
    NULL, // 14
    NULL, // 15
    &PrecisionVar4, // 16
    &PrecisionVar5, // 17
    &PrecisionVar6, // 18
    &PrecisionVar7, // 19
    NULL, // 20
    NULL, // 21
    NULL, // 22
    NULL, // 23
    NULL, // 24
    NULL, // 25
    NULL, // 26
    NULL, // 27
    NULL, // 28
    NULL, // 29
    NULL, // 30
    NULL // 31
}; // PrecisionTable0[]
const GED_PRECISION* PrecisionTable1[32] =
{
    NULL, // 0
    NULL, // 1
    NULL, // 2
    NULL, // 3
    &PrecisionVar8, // 4
    NULL, // 5
    NULL, // 6
    NULL, // 7
    NULL, // 8
    NULL, // 9
    NULL, // 10
    NULL, // 11
    NULL, // 12
    NULL, // 13
    NULL, // 14
    NULL, // 15
    NULL, // 16
    NULL, // 17
    NULL, // 18
    NULL, // 19
    &PrecisionVar9, // 20
    NULL, // 21
    NULL, // 22
    NULL, // 23
    NULL, // 24
    NULL, // 25
    NULL, // 26
    NULL, // 27
    NULL, // 28
    NULL, // 29
    NULL, // 30
    NULL // 31
}; // PrecisionTable1[]
const GED_PRECISION* PrecisionTable2[32] =
{
    &PrecisionVar10, // 0
    NULL, // 1
    NULL, // 2
    NULL, // 3
    &PrecisionVar8, // 4
    NULL, // 5
    NULL, // 6
    NULL, // 7
    NULL, // 8
    NULL, // 9
    NULL, // 10
    NULL, // 11
    &PrecisionVar11, // 12
    NULL, // 13
    NULL, // 14
    NULL, // 15
    NULL, // 16
    NULL, // 17
    NULL, // 18
    NULL, // 19
    &PrecisionVar9, // 20
    NULL, // 21
    NULL, // 22
    NULL, // 23
    &PrecisionVar12, // 24
    NULL, // 25
    NULL, // 26
    NULL, // 27
    NULL, // 28
    NULL, // 29
    NULL, // 30
    NULL // 31
}; // PrecisionTable2[]
static GED_PRED_CTRL PredCtrlVar0 = (GED_PRED_CTRL)0;
static GED_PRED_CTRL PredCtrlVar1 = (GED_PRED_CTRL)1;
static GED_PRED_CTRL PredCtrlVar2 = (GED_PRED_CTRL)2;
static GED_PRED_CTRL PredCtrlVar3 = (GED_PRED_CTRL)3;
static GED_PRED_CTRL PredCtrlVar4 = (GED_PRED_CTRL)4;
static GED_PRED_CTRL PredCtrlVar5 = (GED_PRED_CTRL)5;
static GED_PRED_CTRL PredCtrlVar6 = (GED_PRED_CTRL)6;
static GED_PRED_CTRL PredCtrlVar7 = (GED_PRED_CTRL)7;
static GED_PRED_CTRL PredCtrlVar8 = (GED_PRED_CTRL)8;
static GED_PRED_CTRL PredCtrlVar9 = (GED_PRED_CTRL)9;
static GED_PRED_CTRL PredCtrlVar10 = (GED_PRED_CTRL)10;
static GED_PRED_CTRL PredCtrlVar11 = (GED_PRED_CTRL)11;
static GED_PRED_CTRL PredCtrlVar12 = (GED_PRED_CTRL)12;
static GED_PRED_CTRL PredCtrlVar13 = (GED_PRED_CTRL)13;
static GED_PRED_CTRL PredCtrlVar14 = (GED_PRED_CTRL)14;
static GED_PRED_CTRL PredCtrlVar15 = (GED_PRED_CTRL)15;
static GED_PRED_CTRL PredCtrlVar16 = (GED_PRED_CTRL)16;
static GED_PRED_CTRL PredCtrlVar17 = (GED_PRED_CTRL)17;
static GED_PRED_CTRL PredCtrlVar18 = (GED_PRED_CTRL)18;
static GED_PRED_CTRL PredCtrlVar19 = (GED_PRED_CTRL)19;
const GED_PRED_CTRL* PredCtrlTable0[16] =
{
    &PredCtrlVar0, // 0
    &PredCtrlVar1, // 1
    &PredCtrlVar2, // 2
    &PredCtrlVar3, // 3
    &PredCtrlVar4, // 4
    &PredCtrlVar5, // 5
    &PredCtrlVar6, // 6
    &PredCtrlVar7, // 7
    &PredCtrlVar8, // 8
    &PredCtrlVar9, // 9
    &PredCtrlVar10, // 10
    &PredCtrlVar11, // 11
    &PredCtrlVar12, // 12
    &PredCtrlVar13, // 13
    NULL, // 14
    NULL // 15
}; // PredCtrlTable0[]
const GED_PRED_CTRL* PredCtrlTable1[16] =
{
    &PredCtrlVar0, // 0
    &PredCtrlVar1, // 1
    &PredCtrlVar14, // 2
    &PredCtrlVar15, // 3
    &PredCtrlVar16, // 4
    &PredCtrlVar17, // 5
    &PredCtrlVar6, // 6
    &PredCtrlVar7, // 7
    NULL, // 8
    NULL, // 9
    NULL, // 10
    NULL, // 11
    NULL, // 12
    NULL, // 13
    NULL, // 14
    NULL // 15
}; // PredCtrlTable1[]
const GED_PRED_CTRL* PredCtrlTable2[4] =
{
    &PredCtrlVar0, // 0
    &PredCtrlVar1, // 1
    &PredCtrlVar18, // 2
    &PredCtrlVar19 // 3
}; // PredCtrlTable2[]
static GED_PRED_INV PredInvVar0 = (GED_PRED_INV)0;
static GED_PRED_INV PredInvVar1 = (GED_PRED_INV)1;
const GED_PRED_INV* PredInvTable0[2] =
{
    &PredInvVar0, // 0
    &PredInvVar1 // 1
}; // PredInvTable0[]
static GED_REG_FILE RegFileVar0 = (GED_REG_FILE)0;
static GED_REG_FILE RegFileVar1 = (GED_REG_FILE)1;
static GED_REG_FILE RegFileVar2 = (GED_REG_FILE)2;
const GED_REG_FILE* RegFileTable0[4] =
{
    &RegFileVar0, // 0
    &RegFileVar1, // 1
    NULL, // 2
    NULL // 3
}; // RegFileTable0[]
const GED_REG_FILE* RegFileTable1[4] =
{
    &RegFileVar0, // 0
    &RegFileVar1, // 1
    NULL, // 2
    &RegFileVar2 // 3
}; // RegFileTable1[]
const GED_REG_FILE* RegFileTable2[4] =
{
    &RegFileVar0, // 0
    NULL, // 1
    NULL, // 2
    &RegFileVar2 // 3
}; // RegFileTable2[]
const GED_REG_FILE* RegFileTable3[4] =
{
    NULL, // 0
    &RegFileVar1, // 1
    NULL, // 2
    &RegFileVar2 // 3
}; // RegFileTable3[]
const GED_REG_FILE* RegFileTable4[4] =
{
    &RegFileVar0, // 0
    NULL, // 1
    NULL, // 2
    NULL // 3
}; // RegFileTable4[]
const GED_REG_FILE* RegFileTable5[4] =
{
    NULL, // 0
    &RegFileVar1, // 1
    NULL, // 2
    NULL // 3
}; // RegFileTable5[]
const GED_REG_FILE* RegFileTable6[2] =
{
    &RegFileVar0, // 0
    &RegFileVar1 // 1
}; // RegFileTable6[]
const GED_REG_FILE* RegFileTable7[2] =
{
    &RegFileVar1, // 0
    &RegFileVar2 // 1
}; // RegFileTable7[]
const GED_REG_FILE* RegFileTable8[2] =
{
    &RegFileVar1, // 0
    &RegFileVar0 // 1
}; // RegFileTable8[]
const GED_REG_FILE* RegFileTable9[2] =
{
    &RegFileVar1, // 0
    NULL // 1
}; // RegFileTable9[]
const GED_REG_FILE* RegFileTable10[2] =
{
    &RegFileVar2, // 0
    &RegFileVar0 // 1
}; // RegFileTable10[]
const GED_REG_FILE* RegFileTable11[2] =
{
    &RegFileVar0, // 0
    NULL // 1
}; // RegFileTable11[]
const GED_REG_FILE* RegFileTable12[2] =
{
    &RegFileVar0, // 0
    &RegFileVar2 // 1
}; // RegFileTable12[]
const GED_REG_FILE* RegFileTable13[4] =
{
    &RegFileVar0, // 0
    NULL, // 1
    &RegFileVar2, // 2
    &RegFileVar2 // 3
}; // RegFileTable13[]
const GED_REG_FILE* RegFileTable14[4] =
{
    &RegFileVar0, // 0
    &RegFileVar1, // 1
    &RegFileVar2, // 2
    &RegFileVar2 // 3
}; // RegFileTable14[]
static GED_REP_CTRL RepCtrlVar0 = (GED_REP_CTRL)0;
static GED_REP_CTRL RepCtrlVar1 = (GED_REP_CTRL)1;
const GED_REP_CTRL* RepCtrlTable0[2] =
{
    &RepCtrlVar0, // 0
    &RepCtrlVar1 // 1
}; // RepCtrlTable0[]
static GED_RETURN_DATA_CONTROL ReturnDataControlVar0 = (GED_RETURN_DATA_CONTROL)0;
static GED_RETURN_DATA_CONTROL ReturnDataControlVar1 = (GED_RETURN_DATA_CONTROL)1;
const GED_RETURN_DATA_CONTROL* ReturnDataControlTable0[2] =
{
    &ReturnDataControlVar0, // 0
    &ReturnDataControlVar1 // 1
}; // ReturnDataControlTable0[]
static GED_SATURATE SaturateVar0 = (GED_SATURATE)0;
static GED_SATURATE SaturateVar1 = (GED_SATURATE)1;
const GED_SATURATE* SaturateTable0[2] =
{
    &SaturateVar0, // 0
    &SaturateVar1 // 1
}; // SaturateTable0[]
static GED_SFID SFIDVar0 = (GED_SFID)0;
static GED_SFID SFIDVar1 = (GED_SFID)1;
static GED_SFID SFIDVar2 = (GED_SFID)2;
static GED_SFID SFIDVar3 = (GED_SFID)3;
static GED_SFID SFIDVar4 = (GED_SFID)4;
static GED_SFID SFIDVar5 = (GED_SFID)5;
static GED_SFID SFIDVar6 = (GED_SFID)6;
static GED_SFID SFIDVar7 = (GED_SFID)7;
static GED_SFID SFIDVar8 = (GED_SFID)8;
static GED_SFID SFIDVar9 = (GED_SFID)9;
static GED_SFID SFIDVar10 = (GED_SFID)10;
static GED_SFID SFIDVar11 = (GED_SFID)11;
static GED_SFID SFIDVar12 = (GED_SFID)12;
static GED_SFID SFIDVar13 = (GED_SFID)13;
static GED_SFID SFIDVar14 = (GED_SFID)14;
static GED_SFID SFIDVar15 = (GED_SFID)15;
static GED_SFID SFIDVar16 = (GED_SFID)16;
static GED_SFID SFIDVar17 = (GED_SFID)17;
static GED_SFID SFIDVar18 = (GED_SFID)18;
static GED_SFID SFIDVar19 = (GED_SFID)19;
static GED_SFID SFIDVar20 = (GED_SFID)20;
const GED_SFID* SFIDTable0[16] =
{
    &SFIDVar0, // 0
    NULL, // 1
    &SFIDVar1, // 2
    &SFIDVar2, // 3
    &SFIDVar3, // 4
    &SFIDVar4, // 5
    &SFIDVar5, // 6
    &SFIDVar6, // 7
    &SFIDVar7, // 8
    &SFIDVar8, // 9
    &SFIDVar9, // 10
    &SFIDVar10, // 11
    &SFIDVar11, // 12
    &SFIDVar12, // 13
    NULL, // 14
    NULL // 15
}; // SFIDTable0[]
const GED_SFID* SFIDTable1[16] =
{
    &SFIDVar0, // 0
    &SFIDVar13, // 1
    &SFIDVar1, // 2
    &SFIDVar2, // 3
    &SFIDVar3, // 4
    &SFIDVar4, // 5
    &SFIDVar5, // 6
    &SFIDVar14, // 7
    &SFIDVar15, // 8
    &SFIDVar8, // 9
    &SFIDVar9, // 10
    &SFIDVar10, // 11
    &SFIDVar11, // 12
    &SFIDVar16, // 13
    &SFIDVar17, // 14
    &SFIDVar18 // 15
}; // SFIDTable1[]
const GED_SFID* SFIDTable2[16] =
{
    &SFIDVar0, // 0
    NULL, // 1
    &SFIDVar1, // 2
    &SFIDVar2, // 3
    &SFIDVar3, // 4
    &SFIDVar4, // 5
    &SFIDVar5, // 6
    &SFIDVar14, // 7
    &SFIDVar15, // 8
    &SFIDVar8, // 9
    &SFIDVar9, // 10
    &SFIDVar10, // 11
    &SFIDVar11, // 12
    &SFIDVar16, // 13
    &SFIDVar17, // 14
    &SFIDVar18 // 15
}; // SFIDTable2[]
const GED_SFID* SFIDTable3[16] =
{
    &SFIDVar0, // 0
    NULL, // 1
    &SFIDVar1, // 2
    &SFIDVar2, // 3
    &SFIDVar19, // 4
    &SFIDVar4, // 5
    &SFIDVar5, // 6
    &SFIDVar6, // 7
    &SFIDVar7, // 8
    &SFIDVar20, // 9
    &SFIDVar9, // 10
    &SFIDVar10, // 11
    NULL, // 12
    NULL, // 13
    NULL, // 14
    NULL // 15
}; // SFIDTable3[]
const GED_SFID* SFIDTable4[16] =
{
    &SFIDVar0, // 0
    NULL, // 1
    &SFIDVar1, // 2
    &SFIDVar2, // 3
    &SFIDVar19, // 4
    &SFIDVar4, // 5
    &SFIDVar5, // 6
    &SFIDVar6, // 7
    &SFIDVar7, // 8
    &SFIDVar20, // 9
    &SFIDVar9, // 10
    &SFIDVar10, // 11
    &SFIDVar11, // 12
    &SFIDVar12, // 13
    NULL, // 14
    NULL // 15
}; // SFIDTable4[]
static GED_SIMDMODE SIMDModeVar0 = (GED_SIMDMODE)0;
static GED_SIMDMODE SIMDModeVar1 = (GED_SIMDMODE)1;
static GED_SIMDMODE SIMDModeVar2 = (GED_SIMDMODE)2;
const GED_SIMDMODE* SIMDModeTable0[4] =
{
    &SIMDModeVar0, // 0
    &SIMDModeVar1, // 1
    &SIMDModeVar2, // 2
    NULL // 3
}; // SIMDModeTable0[]
const GED_SIMDMODE* SIMDModeTable1[2] =
{
    &SIMDModeVar1, // 0
    &SIMDModeVar2 // 1
}; // SIMDModeTable1[]
static GED_SLOT_GROUP SlotGroupVar0 = (GED_SLOT_GROUP)0;
static GED_SLOT_GROUP SlotGroupVar1 = (GED_SLOT_GROUP)1;
static GED_SLOT_GROUP SlotGroupVar2 = (GED_SLOT_GROUP)2;
const GED_SLOT_GROUP* SlotGroupTable0[4] =
{
    &SlotGroupVar0, // 0
    &SlotGroupVar1, // 1
    &SlotGroupVar2, // 2
    NULL // 3
}; // SlotGroupTable0[]
const GED_SLOT_GROUP* SlotGroupTable1[2] =
{
    &SlotGroupVar1, // 0
    &SlotGroupVar2 // 1
}; // SlotGroupTable1[]
static GED_SRC_MOD SrcModVar0 = (GED_SRC_MOD)0;
static GED_SRC_MOD SrcModVar1 = (GED_SRC_MOD)1;
static GED_SRC_MOD SrcModVar2 = (GED_SRC_MOD)2;
static GED_SRC_MOD SrcModVar3 = (GED_SRC_MOD)3;
const GED_SRC_MOD* SrcModTable0[4] =
{
    &SrcModVar0, // 0
    &SrcModVar1, // 1
    &SrcModVar2, // 2
    &SrcModVar3 // 3
}; // SrcModTable0[]
const GED_SRC_MOD* SrcModTable1[4] =
{
    &SrcModVar0, // 0
    NULL, // 1
    NULL, // 2
    NULL // 3
}; // SrcModTable1[]
static GED_SUB_BYTE_PRECISION SubBytePrecisionVar0 = (GED_SUB_BYTE_PRECISION)0;
static GED_SUB_BYTE_PRECISION SubBytePrecisionVar1 = (GED_SUB_BYTE_PRECISION)1;
static GED_SUB_BYTE_PRECISION SubBytePrecisionVar2 = (GED_SUB_BYTE_PRECISION)2;
static GED_SUB_BYTE_PRECISION SubBytePrecisionVar3 = (GED_SUB_BYTE_PRECISION)3;
static GED_SUB_BYTE_PRECISION SubBytePrecisionVar4 = (GED_SUB_BYTE_PRECISION)4;
static GED_SUB_BYTE_PRECISION SubBytePrecisionVar5 = (GED_SUB_BYTE_PRECISION)5;
static GED_SUB_BYTE_PRECISION SubBytePrecisionVar6 = (GED_SUB_BYTE_PRECISION)6;
const GED_SUB_BYTE_PRECISION* SubBytePrecisionTable0[4] =
{
    &SubBytePrecisionVar0, // 0
    &SubBytePrecisionVar1, // 1
    &SubBytePrecisionVar2, // 2
    &SubBytePrecisionVar3 // 3
}; // SubBytePrecisionTable0[]
const GED_SUB_BYTE_PRECISION* SubBytePrecisionTable1[4] =
{
    &SubBytePrecisionVar0, // 0
    &SubBytePrecisionVar4, // 1
    &SubBytePrecisionVar5, // 2
    &SubBytePrecisionVar6 // 3
}; // SubBytePrecisionTable1[]
const GED_SUB_BYTE_PRECISION* SubBytePrecisionTable2[4] =
{
    &SubBytePrecisionVar0, // 0
    NULL, // 1
    NULL, // 2
    NULL // 3
}; // SubBytePrecisionTable2[]
const GED_SUB_BYTE_PRECISION* SubBytePrecisionTable3[4] =
{
    &SubBytePrecisionVar0, // 0
    &SubBytePrecisionVar1, // 1
    &SubBytePrecisionVar2, // 2
    NULL // 3
}; // SubBytePrecisionTable3[]
const GED_SUB_BYTE_PRECISION* SubBytePrecisionTable4[4] =
{
    &SubBytePrecisionVar0, // 0
    &SubBytePrecisionVar4, // 1
    &SubBytePrecisionVar5, // 2
    NULL // 3
}; // SubBytePrecisionTable4[]
static GED_SUB_FUNC_ID SubFuncIDVar0 = (GED_SUB_FUNC_ID)0;
static GED_SUB_FUNC_ID SubFuncIDVar1 = (GED_SUB_FUNC_ID)1;
static GED_SUB_FUNC_ID SubFuncIDVar2 = (GED_SUB_FUNC_ID)2;
static GED_SUB_FUNC_ID SubFuncIDVar3 = (GED_SUB_FUNC_ID)3;
static GED_SUB_FUNC_ID SubFuncIDVar4 = (GED_SUB_FUNC_ID)4;
static GED_SUB_FUNC_ID SubFuncIDVar5 = (GED_SUB_FUNC_ID)5;
static GED_SUB_FUNC_ID SubFuncIDVar6 = (GED_SUB_FUNC_ID)6;
const GED_SUB_FUNC_ID* SubFuncIDTable0[8] =
{
    NULL, // 0
    NULL, // 1
    NULL, // 2
    &SubFuncIDVar0, // 3
    &SubFuncIDVar1, // 4
    NULL, // 5
    NULL, // 6
    NULL // 7
}; // SubFuncIDTable0[]
const GED_SUB_FUNC_ID* SubFuncIDTable1[8] =
{
    &SubFuncIDVar2, // 0
    &SubFuncIDVar3, // 1
    &SubFuncIDVar4, // 2
    &SubFuncIDVar0, // 3
    &SubFuncIDVar1, // 4
    &SubFuncIDVar5, // 5
    &SubFuncIDVar6, // 6
    NULL // 7
}; // SubFuncIDTable1[]
static GED_SWIZZLE SwizzleVar0 = (GED_SWIZZLE)0;
static GED_SWIZZLE SwizzleVar1 = (GED_SWIZZLE)1;
static GED_SWIZZLE SwizzleVar2 = (GED_SWIZZLE)2;
static GED_SWIZZLE SwizzleVar3 = (GED_SWIZZLE)3;
const GED_SWIZZLE* SwizzleTable0[4] =
{
    &SwizzleVar0, // 0
    &SwizzleVar1, // 1
    &SwizzleVar2, // 2
    &SwizzleVar3 // 3
}; // SwizzleTable0[]
static GED_SYNC_FC SyncFCVar0 = (GED_SYNC_FC)0;
static GED_SYNC_FC SyncFCVar1 = (GED_SYNC_FC)1;
static GED_SYNC_FC SyncFCVar2 = (GED_SYNC_FC)2;
static GED_SYNC_FC SyncFCVar3 = (GED_SYNC_FC)3;
static GED_SYNC_FC SyncFCVar4 = (GED_SYNC_FC)4;
static GED_SYNC_FC SyncFCVar5 = (GED_SYNC_FC)5;
static GED_SYNC_FC SyncFCVar6 = (GED_SYNC_FC)6;
const GED_SYNC_FC* SyncFCTable0[16] =
{
    &SyncFCVar0, // 0
    &SyncFCVar1, // 1
    &SyncFCVar2, // 2
    &SyncFCVar3, // 3
    NULL, // 4
    NULL, // 5
    NULL, // 6
    NULL, // 7
    NULL, // 8
    NULL, // 9
    NULL, // 10
    NULL, // 11
    NULL, // 12
    NULL, // 13
    &SyncFCVar4, // 14
    &SyncFCVar5 // 15
}; // SyncFCTable0[]
const GED_SYNC_FC* SyncFCTable1[16] =
{
    &SyncFCVar0, // 0
    NULL, // 1
    &SyncFCVar2, // 2
    &SyncFCVar3, // 3
    NULL, // 4
    NULL, // 5
    NULL, // 6
    NULL, // 7
    NULL, // 8
    NULL, // 9
    NULL, // 10
    NULL, // 11
    NULL, // 12
    &SyncFCVar6, // 13
    &SyncFCVar4, // 14
    &SyncFCVar5 // 15
}; // SyncFCTable1[]
static GED_THREAD_CTRL ThreadCtrlVar0 = (GED_THREAD_CTRL)0;
static GED_THREAD_CTRL ThreadCtrlVar1 = (GED_THREAD_CTRL)1;
static GED_THREAD_CTRL ThreadCtrlVar2 = (GED_THREAD_CTRL)2;
static GED_THREAD_CTRL ThreadCtrlVar3 = (GED_THREAD_CTRL)3;
const GED_THREAD_CTRL* ThreadCtrlTable0[4] =
{
    &ThreadCtrlVar0, // 0
    &ThreadCtrlVar1, // 1
    NULL, // 2
    &ThreadCtrlVar2 // 3
}; // ThreadCtrlTable0[]
const GED_THREAD_CTRL* ThreadCtrlTable1[4] =
{
    &ThreadCtrlVar0, // 0
    &ThreadCtrlVar1, // 1
    &ThreadCtrlVar3, // 2
    &ThreadCtrlVar2 // 3
}; // ThreadCtrlTable1[]
const GED_THREAD_CTRL* ThreadCtrlTable2[2] =
{
    &ThreadCtrlVar0, // 0
    &ThreadCtrlVar1 // 1
}; // ThreadCtrlTable2[]
const GED_THREAD_CTRL* ThreadCtrlTable3[4] =
{
    &ThreadCtrlVar0, // 0
    &ThreadCtrlVar1, // 1
    &ThreadCtrlVar3, // 2
    NULL // 3
}; // ThreadCtrlTable3[]
